/**
  ******************************************************************************
  * @file    PT32x031x.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1
  * @brief   
  *                
  *
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/** @addtogroup CMSIS
  * @{
  */

/** @addtogroup PT32x031
  * @{
  */
    
#ifndef PT32x031x_H
#define PT32x031x_H

#ifdef __cplusplus
 extern "C" {
#endif

#if defined (__CC_ARM)
#pragma anon_unions
#endif	

/** @addtogroup Library_configuration_section
  * @{
  */
  
/* Uncomment the line below according to the target PT32F0 device used in your 
   application 
  */

#if !defined  USE_STDPERIPH_DRIVER
/**
 * @brief Comment the line below if you will not use the peripherals drivers.
   In this case, these drivers will not be included and the application code will 
   be based on direct access to peripherals registers 
   */
  /*#define USE_STDPERIPH_DRIVER*/
#endif /* USE_STDPERIPH_DRIVER */

/**
  * @}
  */
  
/** @addtogroup Configuration_section_for_CMSIS
  * @{
  */

/**
 * @brief PT32x031 Interrupt Number Definition, according to the selected device 
 *        in @ref Library_configuration_section 
 */
#define __CM0_REV                 0 /*!< Core Revision r0p0                            */
#define __MPU_PRESENT             0 /*!< PT32F0xx do not provide MPU                   */
#define __NVIC_PRIO_BITS          2 /*!< PT32F0xx uses 2 Bits for the Priority Levels  */
#define __Vendor_SysTickConfig    0 /*!< Set to 1 if different SysTick Config is used  */

/*!< Interrupt Number Definition */	
typedef enum IRQn
{
/******  Cortex-M0 Processor Exceptions Numbers ***************************************************/
  NonMaskableInt_IRQn     = -14,       /*!< 2 Non Maskable Interrupt                              */
  HardFault_IRQn          = -13,      /*!< 3 Cortex-M0 Hard Fault Interrupt                       */
  SVCall_IRQn             = -5,       /*!< 11 Cortex-M0 SV Call Interrupt                         */
  PendSV_IRQn             = -2,       /*!< 14 Cortex-M0 Pend SV Interrupt                         */
  SysTick_IRQn            = -1,       /*!< 15 Cortex-M0 System Tick Interrupt                     */

//#if defined (PT32x031)
/******   PT32x031 Specific Interrupt Numbers *******************************************************/
	SWDG_IRQn               =  0 ,     /* WDG        Interrupt  */
	CLKFAIL_IRQn            =  1 ,      /* CLK_FAIL    Interrupt 	*/
	IFMC_IRQn              	=  3 ,      /* FLASH       Interrupt 	*/
	EXTIA_IRQn              =  5 ,      /* PA          Interrupt 	*/
	EXTIB_IRQn              =  6 ,      /* PB          Interrupt 	*/
	EXTIF_IRQn              =  7 ,      /* CNTTT          Interrupt 	*/
	
	CMP0_IRQn        				=  9 ,      /* Comparator0 Interrupt 	*/
	CMP1_IRQn        				=  10,      /* Comparator1 Interrupt 	*/
	ADC_IRQn                =  12,      /* ADC         Interrupt 	*/
	TIM1_IRQn            		=  13,      /* TIMER1      Interrupt 	*/ 
	TIM0_IRQn            		=  14,      /* TIMER0      Interrupt 	*/
	TIM4_IRQn             	=  15,      /* TIMER4      Interrupt 	*/
	TIM3_IRQn             	=  16,      /* TIMER3      Interrupt 	*/
	TIM2_IRQn             	=  17,      /* TIMER2      Interrupt 	*/
	LED_IRQn                =  18,      /* LED         Interrupt 	*/
	PVD_IRQn                =  20,      /* PVD         Interrupt 	*/

	I2C0_IRQn               =  23,      /* I2C0        Interrupt 	*/
	I2C1_IRQn               =  24,      /* I2C1        Interrupt 	*/
	SPI0_IRQn               =  25,      /* SPI0        Interrupt 	*/
	SPI1_IRQn               =  26,      /* SPI1        Interrupt 	*/
	UART0_IRQn              =  27,      /* UART0       Interrupt 	*/
	UART1_IRQn              =  28,      /* UART1       Interrupt 	*/
//#endif /* PT32x031 */
} IRQn_Type;

/**
  * @}
  */


#include "core_cm0.h"
#include "PT32_Type.h"
#include <stdint.h>

/** @addtogroup Exported_types
  * @{
  */  

typedef enum {RESET = 0, SET = !RESET} FlagStatus, ITStatus, RemapStatus, ProtectStatus;

typedef enum {DISABLE = 0, ENABLE = !DISABLE} FunctionalState;
#define IS_FUNCTIONAL_STATE(STATE) (((STATE) == DISABLE) || ((STATE) == ENABLE))


#define wb(addr, value)     (*((u8  volatile *) (addr)) = value)
#define rb(addr)            (*((u8  volatile *) (addr)))
#define whw(addr, value)    (*((u16 volatile *) (addr)) = value)
#define rhw(addr)           (*((u16 volatile *) (addr)))
#define ww(addr, value)     (*((u32 volatile *) (addr)) = value)
#define rw(addr)            (*((u32 volatile *) (addr)))

#define ResetBit_BB(Addr, BitNumber) (rw(Addr) &= ~(1UL << BitNumber))
#define SetBit_BB(Addr, BitNumber)   (rw(Addr) |= (1UL << BitNumber))
#define GetBit_BB(Addr, BitNumber)   ((rw(Addr) >> BitNumber) & 1UL)

typedef enum {ERROR = 0, SUCCESS = !ERROR} ErrorStatus;

typedef enum {FALSE = 0, TRUE = !FALSE} bool;

/** @addtogroup Peripheral_registers_structures
  * @{
  */   

/** @addtogroup Peripheral_memory_map
  * @{
  */

/**
 * @brief Cyclic Redundancy Check
 */
typedef struct
{                                                                              
  __IO u32 CR;               /*!< 0x000 CRC Control Register                                           */
  __IO u32 SEED;              /*!< 0x004 CRC Seed Register                                              */	
  __IO u32 POLY;             /*!< 0x008 CRC polynomial Register                                        */
  __IO u32 DIN;              /*!< 0x00C CRC Data INPUT Register                                        */
  __IO u32 DOUT;             /*!< 0x010 CRC Data OUT Register                                          */
} CRC_TypeDef;

/** @defgroup PWR_TypeDef
* @{
*/
typedef struct
{
	__IO u32 PVDR;				 /*!< Offset: 0x000   PWR Power Voltage Detect Control Register (R/W) */
} PWR_TypeDef;

/** @defgroup RCC_TypeDef
* @{
*/

typedef struct
{
	__IO u32 HSECR1;  		/*!< Offset: 0x000 	 RCC HSE Control Register1 							(R/W) */
	__IO u32 HSECR2;  		/*!< Offset: 0x004 	 RCC HSE Control Register2 							(R/W) */
	__IO u32 HSICR;				/*!< Offset: 0x008 	 RCC HSI Control Register  							(R/W) */
	__IO u32 LSICR;				/*!< Offset: 0x00C 	 RCC LSI Control Register  							(R/W) */
	__IO u32 PCR;					/*!< Offset: 0x010 	 RCC PLL Control Register  							(R/W) */
	u32 RESERVED0[2];  		/*!< Offset: 0x010   Reserved 																		*/
	__IO u32 MCOR;      	/*!< Offset: 0x01C 	 RCC MCO Control Register  							(R/W) */
	u32 RESERVED1[30201];	/*!< Offset: 0x03C   Reserved 																		*/
	__IO u32 CFGR;				/*!< Offset: 0x4001F00C RCC Clock Configuration Register 			  (R/W) */
	__IO u32 RSR;					/*!< Offset: 0x4001F010 RCC Reset State Register  							(R/W) */
	__O  u32 ASRCR;				/*!< Offset: 0x4001F014 RCC Advanced Software Control Register  (W) */
	__IO u32 RCR;					/*!< Offset: 0x4001F018 RCC Reset Control Register              (R/W) */
} RCC_TypeDef;


/** 
  * @brief General Purpose IO  
  */

typedef struct
{
	__IO u32  DR;        	/*!< Offset: 0x000 DATA Register 														 (R/W) */
	u32  RESERVED1;       /*!< Offset: 0x004 Reserved 																			 */
	__IO u32  OES;				/*!< Offset: 0x008 Output Enable Set Register  							 (R/W) */
	__O  u32  OEC; 				/*!< Offset: 0x00C Output Enable Clear Register  						   (W) */
	u32  RESERVED2[11];		/*!< Offset: 0x010 Reserved 																			 */
	__IO u32  PUS;				/*!< Offset: 0x03C Pull Up Set Register  										 (R/W) */
	__O  u32  PUC;				/*!< Offset: 0x040 Pull Up Clear Register  									   (W) */
	__IO u32  PDS;				/*!< Offset: 0x044 Pull Down Set Register  									 (R/W) */
	__O  u32  PDC;				/*!< Offset: 0x048 Pull Down Clear Register  								   (W) */
	__IO u32  ODS;				/*!< Offset: 0x05C Open Drain Set Register  								 (R/W) */
	__O  u32  ODC;				/*!< Offset: 0x050 Open Drain Clear Register  							   (W) */
	u32  RESERVED3[235];  /*!< Offset: 0x054 Reserved 																		 */
__IO u32  MASKL[256];    	   /*!< Offset: 0x400 - 0x7FC Lower byte Masked Access Register (R/W) */
__IO u32  MASKH[256];    	   /*!< Offset: 0x800 - 0xBFC Upper byte Masked Access Register (R/W) */
} GPIO_TypeDef;

/** @defgroup AFIO_TypeDef
* @{
*/
typedef struct
{
	__IO u32  AFS0;	      /*!< Offset: 0x000 Alternate Function Set Register0/1 	(R/W) */
	__O  u32  AFC;    	  /*!< Offset: 0x008 Alternate Function Clear Register0  	  (W) */
	u32 RESERVED0[15];	  /*!< Offset: 0x00C Reserved 																	*/
	__IO u32  ANAS;				/*!< Offset: 0x048 Analog function Set Register  				(R/W) */
	__O  u32  ANAC;				/*!< Offset: 0x04C Analog function Clear Register  			  (W) */
	__IO u32  AFS1;	      /*!< Offset: 0x000 Alternate Function Set Register0/1 	(R/W) */	
} AFIO_TypeDef;

/** @defgroup EXTI_TypeDef
* @{
*/
typedef struct
{
	__IO u32  IES;     	/*!< Offset: 0x000 Interrupt Enable Set Register  	 (R/W) */
	__O  u32  IEC;    	/*!< Offset: 0x004 Interrupt Enable Clear Register     (W) */
	__IO u32  ITS;      /*!< Offset: 0x008 Interrupt Type Set Register0  		 (R/W) */
	__O  u32  ITC;      /*!< Offset: 0x00C Interrupt Type Clear Register0      (W) */
	__IO u32  ITDS;	    /*!< Offset: 0x010 Interrupt Type Set Register1  		 (R/W) */
	__O  u32  ITDC;	    /*!< Offset: 0x014 Interrupt Type Clear Register1  	   (W) */
	__IO u32  PTS;      /*!< Offset: 0x018 Interrupt Polarity Set Register   (R/W) */
	__O  u32  PTC;   	  /*!< Offset: 0x01C Interrupt Polarity Clear Register 	 (W) */
	__IO u32  IF;	      /*!< Offset: 0x020 Interrupt Status Register  			 (R/W) */
} EXTI_TypeDef;


/** 
  * @brief PWM
  */
typedef struct
{
  __IO u32 SR;            			 /*!< offset: 0x000 Interrupt status Register   (R/W)         */
  __IO u32 CR1;            			 /*!< offset: 0x004 Control Register            (R/W)         */
  __IO u32 ITARR;            	 /*!< offset: 0x008 Interrupt Repeat Timers     (R/W)         */
  __IO u32 ITCNT;            	 /*!< offset: 0x00C Interrupt Repeat Timers PSC (R/W)         */
  __IO u32 PSC;            		  	 /*!< offset: 0x010 Prescale Register           (R/W)         */
  u32 RESERVED0;    	/*!< Offset: 0x18  Reserved 																	  		*/
  __IO u32 CNT;             			 /*!< offset: 0x018 Timer Counter Register      (R/W)         */
  __IO u32 CR2;            			 /*!< offset: 0x01C Match Control Register      (R/W)         */
  __IO u32 ARR;            			 /*!< offset: 0x020 Match Value Register0       (R/W)         */
  __IO u32 OCR[4];            			 /*!< offset: 0x024 Match Value Register       (R/W)         */	
  __IO u32 CAPR;             			 /*!< offset: 0x034 Capture Control Register    (R/W)         */
  __IO u32 ICR[4];            			 /*!< offset: 0x038 Capture Value Register     (R/W)         */
  __IO u32 OCMR;            			 /*!< offset: 0x048 Compare Output Register     (R/W)         */
  __IO u32 DTCR;             		   /*!< offset: 0x04C Death Time Register         (R/W)         */	
} PWM_TypeDef;

/** 
  * @brief TIM
  */
typedef struct
{
  __IO u32 SR;            			 /*!< offset: 0x000 Interrupt status Register   (R/W)         */
  __IO u32 CR1;            			 /*!< offset: 0x004 Control Register            (R/W)         */
  __IO u32 PSC;            		  	 /*!< offset: 0x008 Prescale Register           (R/W)         */
    u32 RESERVED0;
  __IO u32 CNT;             			 /*!< offset: 0x010 Timer Counter Register      (R/W)         */
  __IO u32 CR2;            			 /*!< offset: 0x014 Match Control Register      (R/W)         */
  __IO u32 ARR;            			 /*!< offset: 0x018 Match Value Register0       (R/W)         */
} TIM_TypeDef;


/** 
  * @brief Independent WATCHDOG
  */
typedef struct
{
  __IO u32 RLR;   /*!< IWDG Reload register,    Address offset: 0x00 */
  __I  u32 CNT; /*!< IWDG COUNT register,     Address offset: 0x04 */
  __IO u32 CR;    /*!< IWDG Control register,   Address offset: 0x08 */
  __IO u32 KR;  /*!< IWDG Status register,    Address offset: 0x0C */
  __IO u32 SR;   /*!< IWDG Window register,    Address offset: 0x10 */
	__IO u32 RESERVED0[251];        
  __IO u32 LOCK;    /*!< IWDG Window register,    Address offset: 0x400 */			
} WDG_TypeDef;

/** 
  * @brief Serial Peripheral Interface
  */
  
typedef struct
{
  __IO u32 CR1;     /*!< SPI Control register 1                               Address offset: 0x00 */
  __IO u32 CR2;     /*!< SPI Control register 2,                              Address offset: 0x04 */
  __IO u32 DR;        /*!< SPI data register,                                   Address offset: 0x08 */
  __IO u32 SR1;       /*!< SPI Status register,                                 Address offset: 0x0C */	
  __IO u32 BR;      	/*!< SPI Clock prescaler register                         Address offset: 0x10 */
  __IO u32 IE;        /*!< SPI Interrupt ENABLE register                        Address offset: 0x14 */	
  __IO u32 SR2;       /*!< SPI Interrupt Raw Int Status register                Address offset: 0x18 */	
  u32  RESERVED0;			/*!< Reserved,                                            Address offset: 0x1C */
  __IO u32 IC;       /*!< SPI Interrupt Clear Register register                Address offset: 0x20 */		
  u32 RESERVED1; 			/*!< Reserved,                                            Address offset: 0x24 */
  __IO u32 CSS;      /*!< SPI Chip-Select Control register                     Address offset: 0x18 */	
	
} SPI_TypeDef;

/** 
  * @brief Inter-integrated Circuit Interface
  */

typedef struct
{
  __IO u32 CR;       /*!< I2C Control Set register ,         Address offset: 0x00 */
  __I  u32 SR;        /*!< I2C status register,               Address offset: 0x04 */
  __IO u32 DR;        /*!< I2C data register,                 Address offset: 0x08 */	
  __IO u32 OAR;       /*!< I2C Own address register,          Address offset: 0x0C */
	__IO u32 RESERVED[2];
  __IO u32 CCR;       /*!< I2C Control Reset register 2,      Address offset: 0x18 */	
} I2C_TypeDef;

/** 
  * @brief UART 
  */
typedef struct
{
  __IO u32 DR;                    /*!< Offset: 0x000 Buffer Register 		(R/W) */
  __IO u32 CR;                    /*!< Offset: 0x004 Control Register		(R/W) */
  __IO u32 BRR;                   /*!< Offset: 0x008 Baud Rate Register		(R/W) */
  __IO u32 IE;                   /*!< Offset: 0x00C Interrupt Enable Register	(R/W) */
  __IO u32 SR;                    /*!< Offset: 0x010 Status Register		(R/W) */
	u32  RESERVED0;			/*!< Reserved,Address offset: 0x14 */
  __IO u32 TO;                   /*!< Offset: 0x018 Time Out Register  		(R/W) */
  __IO u32 TXFR;                   /*!< Offset: 0x01C TX Buffer Reset Register  	(WO)  */
  __IO u32 RXFR;                   /*!< Offset: 0x020 RX Buffer Reset Register  	(WO)  */
	u32  RESERVED1;			/*!< Reserved,Address offset: 0x24 */
  __IO u32 IMCR;                 /*!< Offset: 0x028 Infra-red Control Register  	(R/W) */
  __IO u32 IMDCR;             /*!< Offset: 0x02C IR TX PWM Control Register  	(R/W) */
} UART_TypeDef;

/** 
  * @brief BEEP
  */
typedef struct
{
	__IO u32 HCR;/*!< BEEP Control register,   Address offset: 0x00 */
	u32  RESERVED0[1015];	/*!< Reserved,Address offset: 0x04 */	
  __IO u32 CR;    /*!< BEEP Control register,   Address: 0x40002800 */
} BEEP_TypeDef;

/** 
  * @briefOp OPA
  */
  
typedef struct
{
  __IO u32 CR1;       /*!< OPA Control register1,Address offset: 0x00 */
  __IO u32 CR2;       /*!< OPA Control register2,Address offset: 0x04 */
} OPA_TypeDef;


/** 
  * @briefOp CMP
  */
  
typedef struct
{
  __IO u32 CR1;       /*!< Comparator Control register1                         Address offset: 0x00 */
  __IO u32 CR2;       /*!< Comparator Control register2                         Address offset: 0x04 */
	u32  RESERVED0;	/*!< Reserved,Address offset: 0x08 */
  __IO u32 IE;        /*!< Interrupt ENABLE register                            Address offset: 0x0C */	
  __IO u32 SR;       /*!< Interrupt Int Status register                        Address offset: 0x10 */
  __IO u32 CR3; /*!< Comparator initialization delay configuration        Address offset: 0x14 */	
} CMP_TypeDef;

/** @defgroup LDAC_TypeDef
* @{
*/
typedef struct
{
	__IO u32 CR;       /*!< Offset: 0x000  LDAC Control Register  (R/W) */
} LDAC_TypeDef;

/** 
  * @brief 7SEG LED Display Interface
  */
typedef struct
{
  __IO u32 CR1;        /*!< LED Control register 1                               Address offset: 0x00 */
  __IO u32 PSC;      /*!< LED Clock prescaler register                         Address offset: 0x04 */
  __IO u32 CR2;        /*!< LED Display Timer Configuration  register            Address offset: 0x08 */	
  __IO u32 DR0;       /*!< LED data0 register                                   Address offset: 0x0C */
  __IO u32 DR1;       /*!< LED data1 register                                   Address offset: 0x10 */	
  __IO u32 DR2;       /*!< LED data2 register                                   Address offset: 0x14 */
  __IO u32 DR3;       /*!< LED data3 register                                   Address offset: 0x18 */	
  __IO u32 SR;       /*!< LED Interrupt Int Status register                    Address offset: 0x1C */			
} LED_TypeDef;

/** 
  * @brief IFMC
  */
typedef struct
{
  __IO u32 CR;                   	/*!< Offset: 0x000 Flash Command Register (R/W) */
  __IO u32 SR;         	         	/*!< Offset: 0x004 Flash Interrupt status Register (R/W) */
  __IO u32 IE;    	             	/*!< Offset: 0x008 Flash Interrupt Enable Register  (R/W) */
  __IO u32 AR;    	              /*!< Offset: 0x00C Flash Address Register (R/W) */
  __IO u32 DR;                    /*!< Offset: 0x010 Flash Programming Data Register0  (R/W) */
  u32  RESERVED0[5];							/*!< Reserved*/
  __IO u32 PSC;        	         	/*!< Offset: 0x028 Flash Erase Clock Division Register  (R/W) */
	u32  RESERVED1[31733];					/*!< Reserved */
	__IO u32 BSR;
	u32  RESERVED2[8];							/*!< Reserved*/
	__IO u32 RPSR;									/*!< Offset: 0x1F024  Read Protection Status Register (R/W) */
} IFMC_TypeDef;	


/** 
  * @brief System timer  
  */

typedef struct
{
	__IO u32  CSR;                               /*!<Offset: 0x010 Control Status Register                       (R/W)  */   
	__IO u32  RVR;                               /*!<Offset: 0x014 Return Value Register                         (R/W)  */
	__IO u32  CVR;                               /*!<Offset: 0x018 Current Value Register                        (R/W)  */
}CMSDK_SYSTICK_TypeDef;


/** 
  * @brief  Analog to Digital Converter  	  
  */
typedef struct
{
  __IO u32 CR1;                    /*!< Offset: 0x000 ADC Control register */
  __IO u32 CR2;         	       /*!< Offset: 0x004 ADC Reset release timer Register (R/W) */
  __IO u32 SR;    	               /*!< Offset: 0x008 ADC Status Register  (R/W) */
  __IO u32 DR;    	               /*!< Offset: 0x00C ADC data register (R/W) */
} ADC_TypeDef;	

/** @defgroup ID_TypeDef
* @{
*/

typedef struct
{
	__I  u32  UDID;     /*!< Offset: 0x000 User Define Identifier Register 					(R) */
	u32  RESERVED0[2]; 	/*!< Offset: 0x004 Reserved 										   							*/
  u32  RESERVED1;			/*!< Offset: 0x008 Reserved 										   							*/
	__I  u32  UID1;   	/*!< Offset: 0x010 Unique Product Identification Register 1 (R) */
	__I  u32  UID2;   	/*!< Offset: 0x014 Unique Product Identification Register 2 (R) */
	__I  u32  UID3;   	/*!< Offset: 0x018 Unique Product Identification Register 3 (R) */
	__I  u32  CID;      /*!< Offset: 0x01C Chip Configration Identifier Register 		(R) */
} ID_TypeDef;


/*Peripheral and SRAM base address */
#define SRAM_BASE       (0x20000000)     /*!< (SRAM      ) Base Address */

#define APB_BASE        (0x40000000)

#define AHB_BASE        (0x48000000)

/* AHB peripherals */
#define GPIOA_BASE      (AHB_BASE + 0x00000000)
#define GPIOB_BASE      (AHB_BASE + 0x00001000)
#define GPIOF_BASE      (AHB_BASE + 0x00002000)

#define EXTIA_BASE			(AHB_BASE + 0x00000018)
#define EXTIB_BASE			(AHB_BASE + 0x00001018)
#define EXTIF_BASE			(AHB_BASE + 0x00002018)

#define AFIOA_BASE			(AHB_BASE + 0x00000010)
#define AFIOB_BASE			(AHB_BASE + 0x00001010)
#define AFIOF_BASE			(AHB_BASE + 0x00002010)

/* APB peripherals */
#define IFMC_BASE      (APB_BASE + 0x00000000)
#define CMP0_BASE      (APB_BASE + 0x00000800)
#define CMP1_BASE      (APB_BASE + 0x00000C00)
#define TIM2_BASE      (APB_BASE + 0x00001000)
#define TIM3_BASE      (APB_BASE + 0x00001400)
#define RCC_BASE     	 (APB_BASE + 0x00001808)
#define TIM4_BASE      (APB_BASE + 0x00001C00)
#define SWDG_BASE      (APB_BASE + 0x00002000)
#define BEEP_BASE      (APB_BASE + 0x00001820)
#define LED_BASE       (APB_BASE + 0x00002C00)
#define IWDG_BASE      (APB_BASE + 0x00003000)
#define SPI1_BASE      (APB_BASE + 0x00003800)
#define CRC_BASE       (APB_BASE + 0x00003C00)
#define UART0_BASE     (APB_BASE + 0x00004400)
#define I2C0_BASE      (APB_BASE + 0x00005400)
#define I2C1_BASE      (APB_BASE + 0x00005800)
#define ADC_BASE       (APB_BASE + 0x00012400)
#define TIM0_BASE      (APB_BASE + 0x00012800)
#define TIM1_BASE      (APB_BASE + 0x00012C00)
#define SPI0_BASE      (APB_BASE + 0x00013000)
#define UART1_BASE     (APB_BASE + 0x00013800)

#define ID_BASE		     (APB_BASE + 0x0001F020)
#define LDAC0_BASE     (APB_BASE + 0x00000808)
#define LDAC1_BASE     (APB_BASE + 0x00000C08)
#define PWR_BASE       (APB_BASE + 0x00001800)

/**
  * @}
  */

/** @addtogroup Peripheral_declaration
  * @{
  */  
#define PWR			((PWR_TypeDef  	   *) PWR_BASE )
#define RCC			((RCC_TypeDef   	 *) RCC_BASE )
#define ID			((ID_TypeDef       *) ID_BASE )

#define GPIOA   ((GPIO_TypeDef     *) GPIOA_BASE )
#define GPIOB   ((GPIO_TypeDef     *) GPIOB_BASE )
#define GPIOF   ((GPIO_TypeDef     *) GPIOF_BASE )

#define AFIOA		((AFIO_TypeDef     *) AFIOA_BASE )
#define AFIOB		((AFIO_TypeDef     *) AFIOB_BASE )
#define AFIOF		((AFIO_TypeDef     *) AFIOF_BASE )

#define EXTIA		((EXTI_TypeDef     *) EXTIA_BASE )
#define EXTIB		((EXTI_TypeDef     *) EXTIB_BASE )
#define EXTIF		((EXTI_TypeDef     *) EXTIF_BASE )

#define UART0   ((UART_TypeDef     *) UART0_BASE )
#define UART1   ((UART_TypeDef     *) UART1_BASE )
#define IFMC    ((IFMC_TypeDef     *) IFMC_BASE )
#define ADC     ((ADC_TypeDef      *) ADC_BASE )
#define I2C0    ((I2C_TypeDef      *) I2C0_BASE )
#define I2C1    ((I2C_TypeDef      *) I2C1_BASE )
#define SPI0    ((SPI_TypeDef      *) SPI0_BASE )
#define SPI1    ((SPI_TypeDef      *) SPI1_BASE )
#define LED     ((LED_TypeDef      *) LED_BASE )
#define CMP0    ((CMP_TypeDef  		 *) CMP0_BASE )
#define CMP1    ((CMP_TypeDef   	 *) CMP1_BASE )
#define OPA0    ((OPA_TypeDef   	 *) CMP0_BASE )
#define OPA1    ((OPA_TypeDef      *) CMP1_BASE )
#define LDAC0		((LDAC_TypeDef   	 *) LDAC0_BASE )
#define LDAC1		((LDAC_TypeDef   	 *) LDAC1_BASE )
#define PWM0    ((PWM_TypeDef      *) TIM0_BASE )
#define PWM1    ((PWM_TypeDef      *) TIM1_BASE )
#define TIM2    ((TIM_TypeDef      *) TIM2_BASE )
#define TIM3    ((TIM_TypeDef      *) TIM3_BASE )
#define TIM4    ((TIM_TypeDef      *) TIM4_BASE )
#define CRC     ((CRC_TypeDef      *) CRC_BASE )
#define IWDG    ((WDG_TypeDef      *) IWDG_BASE )
#define SWDG    ((WDG_TypeDef      *) SWDG_BASE )
#define BEEP    ((BEEP_TypeDef     *) BEEP_BASE )
#define PWR			((PWR_TypeDef  	   *) PWR_BASE )
#define RCC			((RCC_TypeDef   	 *) RCC_BASE )
/**
  * @}
  */

/** @addtogroup Exported_constants
  * @{
  */
  
  /** @addtogroup Peripheral_Registers_Bits_Definition
  * @{
  */
    
/******************************************************************************/
/*                         Peripheral Registers Bits Definition               */
/******************************************************************************/
/******************************************************************************/
/*                                                                            */
/*                      CRC Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for CRC_CR register  *******************/  
#define CRC_CR_EN                ((u32)0x00000001)          /*!< CRC Enable */
#define CRC_CR_CRS               ((u32)0x00000002)          /*!< CRC Initial */
#define CRC_CR_CIS               ((u32)0x00000004)          /*!< CRC DataIn Width */
#define CRC_CR_CISN              ((u32)0x00000008)          /*!< CRC DataIn Width */
#define CRC_CR_CBN               ((u32)0x00000010)          /*!< CRC DataIn Width */
#define CRC_CR_COSN              ((u32)0x00000020)          /*!< CRC DataIn Width */

/*******************  Bit definition for CRC_SEED register  *******************/  
#define CRC_SEED_MASK            ((u32)0x0000FFFF)          /*!< CRC SEED */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_POLY_MASK            ((u32)0x0000FFFF)          /*!< CRC SEED */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_DIN_MASK             ((u32)0x0000FFFF)          /*!< CRC DATA INPUT */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_DOUT_MASK            ((u32)0x0000FFFF)          /*!< CRC DATA OUT */

/******************************************************************************/

/******************************************************************************/
/*                                                                            */
/*                      PWR Function (PWR)                     */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for PWR PVDR register  ******************/
#define PWR_PVDR_PVDE            ((u32)0x00000001)        /*!<  */
#define PWR_PVDR_PLS             ((u32)0x0000000E)        /*!<  */
/********************  Bits definition for RCC CFGR register  ******************/
#define RCC_CFGR_SCW             ((u32)0x00000003)        /*!<  */
#define RCC_CFGR_PLLSRC          ((u32)0x0000000C)        /*!<  */
#define RCC_CFGR_HPRE            ((u32)0x00000070)        /*!<  */
#define RCC_CFGR_PPRE            ((u32)0x00000700)        /*!<  */
#define RCC_CFGR_HSEDE           (u32)0x00001000)        /*!<  */
#define RCC_CFGR_HSEF            ((u32)0x00002000)        /*!<  */
#define RCC_CFGR_PLLDE           ((u32)0x00004000)        /*!<  */
#define RCC_CFGR_PLLF            ((u32)0x00008000)        /*!<  */
#define RCC_CFGR_WKDL            ((u32)0x00030000)        /*!<  */
#define RCC_CFGR_WKCK            ((u32)0x00100000)        /*!<  */

/********************  Bits definition for RCC RSR register  ******************/
#define RCC_RSR_SFR              ((u32)0x00000001)        /*!<  */
#define RCC_RSR_IWDG             ((u32)0x00000002)        /*!<  */
#define RCC_RSR_SWDG             ((u32)0x00000008)        /*!<  */
#define RCC_RSR_HSE              ((u32)0x00000010)        /*!<  */
#define RCC_RSR_PLL              ((u32)0x00000020)        /*!<  */
#define RCC_RSR_POR              ((u32)0x00000040)        /*!<  */
#define RCC_RSR_PIN              ((u32)0x00000080)        /*!<  */
#define RCC_RSR_PVD              ((u32)0x00000100)        /*!<  */


/********************  Bits definition for RCC ASRCR register  ******************/
#define RCC_ASRCR_KEY            ((u32)0x0000AB56)        /*!<  */

/********************  Bits definition for RCC RCR register  ******************/
#define RCC_RCR_HREN             ((u32)0x00000010)        /*!<  */
#define RCC_RCR_PREN             ((u32)0x00000020)        /*!<  */
#define RCC_RCR_PDRE             ((u32)0x00000100)        /*!<  */
#define RCC_RCR_ASFREN           ((u32)0x00000400)        /*!<  */

/******************************************************************************/
/********************  Bits definition for RCC HSECR1 register  ******************/
#define RCC_HSECR1_EN            ((u32)0x00000001)        /*!<  */
#define RCC_HSECR1_ACC           ((u32)0x00000002)        /*!<  */
#define RCC_HSECR1_ECEN          ((u32)0x00000004)        /*!<  */
#define RCC_HSECR1_HSE2D         ((u32)0x00000008)        /*!<  */
#define RCC_HSECR1_HSEFR         ((u32)0x00000010)        /*!<  */
#define RCC_HSECR1_LPF           ((u32)0x00000300)        /*!<  */
#define RCC_HSECR1_LPFB     		 ((u32)0x00000400)        /*!<  */
#define RCC_HSECR1_RDY           ((u32)0x80000000)        /*!<  */

/********************  Bits definition for RCC HSECR2 register  ******************/
#define RCC_HSECR2_CAD           ((u32)0x00000007)        /*!<  */
#define RCC_HSECR2_CS            ((u32)0x00000070)        /*!<  */
#define RCC_HSECR2_FDR           ((u32)0x00000300)        /*!<  */
#define RCC_HSECR2_FDR_1100K     ((u32)0x00000000)        /*!<  */
#define RCC_HSECR2_FDR_800K      ((u32)0x00000100)        /*!<  */
#define RCC_HSECR2_FDR_500K      ((u32)0x00000200)        /*!<  */
#define RCC_HSECR2_FDR_200K      ((u32)0x00000300)        /*!<  */
#define RCC_HSICR_EN             ((u32)0x00000001)        /*!<  */
#define RCC_LSICR_EN             ((u32)0x00000001)        /*!<  */
#define RCC_PCR_EN               ((u32)0x00000001)        /*!<  */
#define RCC_MCOR_COPRE           ((u32)0x00000007)        /*!<  */

/******************************************************************************/
/*                                                                            */
/*                      Analog to Digital Converter (ADC)                     */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for ADC_CR register  ******************/
#define ADC_CR1_EN               ((u32)0x00000001)       /*!< ADC enable control */
#define ADC_CR1_MODE             ((u32)0x00000002)       /*!< Continuous Conversion */
#define ADC_CR1_TRIGS            ((u32)0x0000000C)       /*!< SOCSEL[3:2] bits(ADC trigger source selection) */
#define ADC_CR1_TIMS             ((u32)0x00000030)       /*!< TMRSEL[5:4] bits( ) */
#define ADC_CR1_PSC              ((u32)0x00000300)       /*!< CLKDIV[9:8] bits( ) */
#define ADC_CR1_EOCIE            ((u32)0x00000400)       /*!< End of Conversion interrupt enable */
#define ADC_CR1_ALIGN            ((u32)0x00000800)       /*!< Data Alignment */
#define ADC_CR1_SOC              ((u32)0x00001000)       /*!< ADC start of conversion */
#define ADC_CR1_CHS              ((u32)0x000F0000)        /*!< Channel 12 selection */
#define ADC_CR1_CHS_12           ((u32)0x000C0000)        /*!< Channel 12 selection */
#define ADC_CR1_CHS_11           ((u32)0x000B0000)        /*!< Channel 11 selection */
#define ADC_CR1_CHS_10           ((u32)0x000A0000)        /*!< Channel 10 selection */
#define ADC_CR1_CHS_9            ((u32)0x00090000)        /*!< Channel 9 selection */
#define ADC_CR1_CHS_8            ((u32)0x00080000)        /*!< Channel 8 selection */
#define ADC_CR1_CHS_7            ((u32)0x00070000)        /*!< Channel 7 selection */
#define ADC_CR1_CHS_6            ((u32)0x00060000)        /*!< Channel 6 selection */
#define ADC_CR1_CHS_5            ((u32)0x00050000)        /*!< Channel 5 selection */
#define ADC_CR1_CHS_4            ((u32)0x00040000)        /*!< Channel 4 selection */
#define ADC_CR1_CHS_3            ((u32)0x00030000)        /*!< Channel 3 selection */
#define ADC_CR1_CHS_2            ((u32)0x00020000)        /*!< Channel 2 selection */
#define ADC_CR1_CHS_1            ((u32)0x00010000)        /*!< Channel 1 selection */
#define ADC_CR1_CHS_0            ((u32)0x00000000)        /*!< Channel 0 selection */

/********************  Bits definition for ADC_CR2 register  ******************/
#define ADC_CR2_RDTC             ((u32)0x0000003F)       /*!<  */

/********************  Bits definition for ADC_SR register  ******************/
#define ADC_SR_RDY               ((u32)0x00000001)       /*!< ADC Ready */
#define ADC_SR_EOC               ((u32)0x00000002)       /*!< ADC End of Conversion */

/********************  Bit definition for ADC_DR register  ********************/
#define  ADC_DR_DATA             ((u32)0x0000FFFF)        /*!< Regular data */

/******************************************************************************/
/*                                                                            */
/*                      PWM Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for PWM_SR register  *******************/  
#define PWM_SR_ARF               ((u32)0x00000001)       /*!<ʱƥ0־λ       */
#define PWM_SR_OC1F              ((u32)0x00000002)       /*!<ʱƥ1־λ       */
#define PWM_SR_OC2F              ((u32)0x00000004)       /*!<ʱƥ2־λ       */
#define PWM_SR_OC3F              ((u32)0x00000008)       /*!<ʱƥ3־λ       */
#define PWM_SR_OC4F              ((u32)0x00000010)       /*!<ʱƥ4־λ       */
#define PWM_SR_IC1R              ((u32)0x00000020)       /*!<ʱ1ر־λ */
#define PWM_SR_IC1F              ((u32)0x00000040)       /*!<ʱƥ1½ر־λ */
#define PWM_SR_IC2R              ((u32)0x00000080)       /*!<ʱƥ2ر־λ */
#define PWM_SR_IC2F              ((u32)0x00000100)       /*!<ʱƥ2½ر־λ */
#define PWM_SR_IC3R              ((u32)0x00000200)       /*!<ʱƥ3ر־λ */
#define PWM_SR_IC3F              ((u32)0x00000400)       /*!<ʱƥ3½ر־λ */
#define PWM_SR_IC4R              ((u32)0x00000800)       /*!<ʱƥ4ر־λ */
#define PWM_SR_IC4F              ((u32)0x00001000)       /*!<ʱƥ4½ر־λ */
#define PWM_SR_BIF               ((u32)0x00002000)       /*!<ʱɲ־λ    */

/*******************  Bit definition for PWM_CR1 register  *******************/  
#define PWM_CR1_EN               ((u32)0x00000001)       /*!<ʱʹܿλ        */
#define PWM_CR1_UG               ((u32)0x00000002)       /*!<ʱƥֵ        */
#define PWM_CR1_CLKS             ((u32)0x00000004)       /*!<ʱʱѡ      */

/*******************  Bit definition for PWM_ITARR register  *******************/  
#define PWM_ITARR_ITARR          ((u32)0xF)               /*!<ITARR[3:0]ʱжۼƴλ   */

/*******************  Bit definition for PWM_ITCNT register  *******************/  
#define PWM_ITCNT_ITCNT          ((u32)0xF)               /*!<ITCNT[3:0]ʱжۼƴǰֵ   */

/*******************  Bit definition for PWM_PSC register  *******************/  
#define PWM_PSC_PSC              ((u32)0xFF)               /*!<PSC[7:0]ʱԤƵϵ   */

/*******************  Bit definition for PWM_CNT register  *******************/  
#define PWM_CNT_CNT              ((u32)0xFF)               /*!<CNTTT[15:0]ʱԤƵǰֵ   */

/*******************  Bit definition for PWM_CR2 register  *******************/  
#define PWM_CR2_ARI              ((u32)0x00000001)       /*!<PMW_TCPWM_ARR_ARRƥʱжϿλ        */
#define PWM_CR2_OC1I             ((u32)0x00000002)       /*!<PMW_TCPWM_OCR1_OCRƥʱжϿλ        */
#define PWM_CR2_OC2I             ((u32)0x00000004)       /*!<PMW_TCPWM_OCR2_OCRƥʱжϿλ        */
#define PWM_CR2_OC3I             ((u32)0x00000008)       /*!<PMW_TCPWM_OCR3_OCRƥʱжϿλ        */
#define PWM_CR2_OC4I             ((u32)0x00000010)       /*!<PMW_TCPWM_OCR4_OCRƥʱжϿλ        */
#define PWM_CR2_OPM              ((u32)0x00000020)       /*!<PMW_TCPWM_ARR_ARRƥʱʱֹͣλ      */
#define PWM_CR2_DIR              ((u32)0x00000040)       /*!<PWM_TCλ                       */
#define PWM_CR2_CMS              ((u32)0x00000080)       /*!<PWM_TCλ                   */

/*******************  Bit definition for PWM_ARR register  *******************/  
#define PWM_ARR_ARR              ((u32)0xFFFF)            /*!<ARR[15:0]ʱARRƥֵ   */

/*******************  Bit definition for PWM_OCR1 register  *******************/  
#define PWM_OCR1_OCR             ((u32)0xFFFF)            /*!<MR1[15:0]ʱMR1ƥֵ   */

/*******************  Bit definition for PWM_OCR2 register  *******************/  
#define PWM_OCR2_OCR             ((u32)0xFFFF)            /*!<MR2[15:0]ʱMR2ƥֵ   */

/*******************  Bit definition for PWM_OCR3 register  *******************/  
#define PWM_OCR3_OCR             ((u32)0xFFFF)            /*!<MR3[15:0]ʱMR3ƥֵ   */

/*******************  Bit definition for PWM_OCR4_OCR register  *******************/  
#define PWM_OCR4_OCR             ((u32)0xFFFF)            /*!<MR4[15:0]ʱMR4ƥֵ   */

/*******************  Bit definition for PWM_CAPR register  *******************/  
#define PWM_CAPR_IC1R            ((u32)0x00000001)       /*!<ͨ1ز׽ʹܿ          */
#define PWM_CAPR_IC1F            ((u32)0x00000002)       /*!<ͨ1½ز׽ʹܿ          */
#define PWM_CAPR_IC1RC           ((u32)0x00000004)       /*!<ͨ1ز׽λʹܿ    */
#define PWM_CAPR_IC1I            ((u32)0x00000008)       /*!<ͨ1ز׽жʹܿ          */
#define PWM_CAPR_IC2R            ((u32)0x00000010)       /*!<ͨ2ز׽ʹܿ          */
#define PWM_CAPR_IC2F            ((u32)0x00000020)       /*!<ͨ2½ز׽ʹܿ          */
#define PWM_CAPR_IC2RC           ((u32)0x00000040)       /*!<ͨ2ز׽λʹܿ    */
#define PWM_CAPR_IC2I            ((u32)0x00000080)       /*!<ͨ2ز׽жʹܿ          */
#define PWM_CAPR_IC3R            ((u32)0x00000100)       /*!<ͨ3ز׽ʹܿ          */
#define PWM_CAPR_IC3F            ((u32)0x00000200)       /*!<ͨ3½ز׽ʹܿ          */
#define PWM_CAPR_IC3RC           ((u32)0x00000400)       /*!<ͨ3ز׽λʹܿ    */
#define PWM_CAPR_IC3I            ((u32)0x00000800)       /*!<ͨ3ز׽жʹܿ          */
#define PWM_CAPR_IC4R            ((u32)0x00001000)       /*!<ͨ4ز׽ʹܿ          */
#define PWM_CAPR_IC4F            ((u32)0x00002000)       /*!<ͨ4½ز׽ʹܿ          */
#define PWM_CAPR_IC4RC           ((u32)0x00004000)       /*!<ͨ4ز׽λʹܿ    */
#define PWM_CAPR_IC4I            ((u32)0x00008000)       /*!<ͨ4ز׽жʹܿ          */

/*******************  Bit definition for PWM_ICR1 register  *******************/  
#define PWM_ICR1_ICR             ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ1ر仯ֵ   */

/*******************  Bit definition for PWM_ICR2 register  *******************/ 
#define PWM_ICR2_ICR             ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ2ر仯ֵ   */

/*******************  Bit definition for PWM_ICR3 register  *******************/  
#define PWM_ICR3_ICR             ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ3ر仯ֵ   */

/*******************  Bit definition for PWM_ICR4 register  *******************/  
#define PWM_ICR4_ICR             ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ4ر仯ֵ   */

/*******************  Bit definition for PWM_OCMR register  *******************/  
#define PWM_OCMR_OC1M            ((u32)0x00000003)       /*!<MC1[1:0]  ͨ1Ƚģʽѡ    */
#define PWM_OCMR_OC2M            ((u32)0x00000030)       /*!<MC2[5:4]  ͨ2Ƚģʽѡ    */
#define PWM_OCMR_OC3M            ((u32)0x00000300)       /*!<MC3[9:8] ͨ3Ƚģʽѡ    */
#define PWM_OCMR_OC4M            ((u32)0x00003000)       /*!<MC4[13:12]ͨ4Ƚģʽѡ    */
#define PWM_OCMR_OIS1            ((u32)0x00010000)       /*!<ͨ1ʼֵ                        */
#define PWM_OCMR_OIS2            ((u32)0x00020000)       /*!<ͨ2ʼֵ                        */
#define PWM_OCMR_OIS3            ((u32)0x00040000)       /*!<ͨ3ʼֵ                        */
#define PWM_OCMR_OIS4            ((u32)0x00080000)       /*!<ͨ4ʼֵ                        */
#define PWM_OCMR_OC1NE           ((u32)0x00100000)       /*!<ͨ1ʹ                  */
#define PWM_OCMR_OC2NE           ((u32)0x00200000)       /*!<ͨ2ʹ                  */
#define PWM_OCMR_OC3NE           ((u32)0x00400000)       /*!<ͨ3ʹ                  */
#define PWM_OCMR_OC4NE           ((u32)0x00800000)       /*!<ͨ4ʹ                  */
#define PWM_OCMR_BKE             ((u32)0x01000000)       /*!<ɲʹܿ                       */
#define PWM_OCMR_BKP             ((u32)0x02000000)       /*!<ɲЧƽ                   */
#define PWM_OCMR_BKI             ((u32)0x04000000)       /*!<ɲжʹܿ                   */

/*******************  Bit definition for PWM_DTCR register  *******************/  
#define PWM_DTCR_DT              ((u32)0xFF)              /*!<DT[7:0]ʱ   */

/******************************************************************************/
/*                                                                            */
/*                      TIM Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for TIM_SR register  *******************/  
#define TIM_SR_ARF               ((u32)0x00000001)        /*!<ʱARRֵƥжϱ־λ       */

/*******************  Bit definition for TIM_CR1 register  *******************/  
#define TIM_CR1_EN               ((u32)0x00000001)        /*!<ʱʹܿλ        */
#define TIM_CR1_UG               ((u32)0x00000002)        /*!<ʱƥֵ        */

/*******************  Bit definition for TIM_PSC register  *******************/  
#define TIM_PSC_PSC              ((u32)0xFF)               /*!<PSC[7:0]ʱԤƵϵ   */

/*******************  Bit definition for TIM_CNT register  *******************/  
#define TIM_CNT_CNT              ((u32)0xFFFF)            /*!<CNTTT[15:0]ʱǰֵ   */

/*******************  Bit definition for TIM_CR2 register  *******************/  
#define TIM_CR2_ARI              ((u32)0x00000001)        /*!<TIM_CNT_CNTARRֵƥʱжϿλ          */
#define TIM_CR2_RSTC             ((u32)0x00000002)        /*!<TIM_CNT_CNTARRֵƥʱλλ          */
#define TIM_CR2_OPM              ((u32)0x00000004)        /*!<TIM_CNT_CNTARRֵƥʱֹͣλ        */
#define TIM_CR2_DIR              ((u32)0x00000008)        /*!<TIM_CNT_CNTλ                       */


/*******************  Bit definition for PWM_ARR register  *******************/  
#define TIM_ARR_ARR              ((u32)0xFFFF)            /*!<ARR[15:0]ʱARRƥֵ   */

/******************************************************************************/
/*                                                                            */
/*                        Independent WATCHDOG (WDG)                         */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for WDG_RLR register  *******************/
#define  WDG_RLR_RL               ((u32)0xFFFFFFFF)            /*!< Watchdog counter reload value */

/*******************  Bit definition for WDG_Count register  *******************/ 
#define  WDG_COUNT_COUNT          ((u32)0xFFFFFFFF)            /*!< Watchdog count value          */

/*******************  Bit definition for WDG_CR register  *******************/  
#define  WDG_CR_INTE              ((u32)0x00000001)       /*!< Enable IWDG        */
#define  WDG_CR_RSTE              ((u32)0x00000002)       /*!< RESET IWDG         */
#define  WDG_CR_DBGE              ((u32)0x00000004)       /*!< RESET IWDG         */

/*******************  Bit definition for WDG_RIS register  *******************/  
#define  WDG_RIS_RVU              ((u32)0x00000001)               /*!< Watchdog counter reload value update */

/*******************  Bit definition for WDG_KR register  ********************/
#define  WDG_KR_KEY               ((u32)0xFFFFFFFF)            /*!< Key value (write only, read 0000h) */
#define  WDG_KR_LOCK              ((u32)0x00000001)            /*!< IWDG LOCK        */

/*******************  Bit definition for WDG_RIS register  *******************/  
#define  WDG_EIS_RVU              ((u32)0x00000001)               /*!< Watchdog counter reload value update */

/******************************************************************************/
/*                                                                            */
/*                        Serial Peripheral Interface (SPI)                   */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for SPI_CR0 register  ********************/
#define  SPI_CR1_DFF              ((u32)0x0000000F)         /*!< SPI_data_size */
#define  SPI_CR1_CPOL             ((u32)0x00000040)         /*!< Clock Polarity */
#define  SPI_CR1_CPHA             ((u32)0x00000080)         /*!< Clock Phase */
#define  SPI_CR1_PSC              ((u32)0x0000FF00)         /*!< Post-division factor */
/*******************  Bit definition for SPI_CR1 register  ********************/
#define  SPI_CR2_LBM              ((u32)0x00000001)         /*!< Loopback Mode */
#define  SPI_CR2_EN               ((u32)0x00000002)         /*!< Loopback Mode */
#define  SPI_CR2_MSM              ((u32)0x00000004)         /*!< Master-slave selection */

/********************  Bit definition for SPI_DR register  ********************/
#define  SPI_DR_DR                ((u32)0xFFFF)            /*!< Data Register */

/********************  Bit definition for SPI_SR register  ********************/
#define  SPI_SR1_TXE              ((u32)0x00000001)         /*!< Transmission FIFO is empty */
#define  SPI_SR1_TNF              ((u32)0x00000002)         /*!< Transmission FIFO is not empty */
#define  SPI_SR1_RXNE             ((u32)0x00000004)         /*!< Receiver FIFO is not empty */
#define  SPI_SR1_RXF              ((u32)0x00000008)         /*!< Receiver FIFO is Full */
#define  SPI_SR1_BSY              ((u32)0x00000010)         /*!< Transmission module is busy */

/********************  Bit definition for SPI_BR register  ********************/
#define  SPI_BR_BR                ((u32)0x000000FF)         /*!< Prescaler factor */

/********************  Bit definition for SPI_IE register  ********************/
#define  SPI_IE_OVRE              ((u32)0x00000001)         /*!< Receiver FIFO overflow */
#define  SPI_IE_OTE               ((u32)0x00000002)         /*!< Receiver FIFO Non-empty timeout */
#define  SPI_IE_RXHE              ((u32)0x00000004)         /*!< Receiver FIFO Half-full */
#define  SPI_IE_TXHE              ((u32)0x00000008)         /*!< Transmission FIFO Half-full */

/********************  Bit definition for SPI_SR2 register  ********************/
#define  SPI_SR2_OVR              ((u32)0x00000001)         /*!< Receiver FIFO overflow */
#define  SPI_SR2_OT               ((u32)0x00000002)         /*!< Receiver FIFO Non-empty timeout */
#define  SPI_SR2_RXH              ((u32)0x00000004)         /*!< Receiver FIFO Half-full */
#define  SPI_SR2_TXH              ((u32)0x00000008)         /*!< Transmission FIFO Half-full */

/********************  Bit definition for SPI_EIS register  ********************/
#define  SPI_EIS_RFOVF            ((u32)0x00000001)         /*!< Receiver FIFO overflow */
#define  SPI_EIS_RFNETO           ((u32)0x00000002)         /*!< Receiver FIFO Non-empty timeout */
#define  SPI_EIS_RFHF             ((u32)0x00000004)         /*!< Receiver FIFO Half-full */
#define  SPI_EIS_TFHF             ((u32)0x00000008)         /*!< Transmission FIFO Half-full */

/********************  Bit definition for SPI_IC register  ********************/
#define  SPI_IC_OVR               ((u32)0x00000001)         /*!< Receiver FIFO overflow */
#define  SPI_IC_OT                ((u32)0x00000002)         /*!< Receiver FIFO Non-empty timeout */

/********************  Bit definition for SPI_CSS register  ********************/
#define  SPI_CSS_CSS              ((u32)0x00000004)         /*!< CS is controlled by software  */
#define  SPI_CSS_SWCS             ((u32)0x00000008)         /*!< CS Set Bit by software  */
/******************************************************************************/
/*                                                                            */
/*                   Inter-integrated Circuit Interface (I2C)                 */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for I2C_CR register  *******************/
#define  I2C_CR_PSC0       				((u32)0x00000003)        /*!< System clock division factor bit12  */
#define  I2C_CR_PSC1       				((u32)0x00000080)        /*!< System clock division factor bit2  */
#define  I2C_CR_ACK        				((u32)0x00000004)        /*!< ACK generation (slave mode) */
#define  I2C_CR_SI         				((u32)0x00000008)        /*!< Interrupt status */
#define  I2C_CR_STOP      				((u32)0x00000010)        /*!< STOP generation (master mode) */
#define  I2C_CR_STAR       				((u32)0x00000020)        /*!< START generation */
#define  I2C_CR_EN         				((u32)0x00000040)        /*!< Peripheral enable */

/*******************  Bit definition for I2C_SR register  *******************/
#define  I2C_SR_SR				 				((u32)0x000000F8)

/*******************  Bit definition for I2C_DR register  *******************/
#define  I2C_DR_DR         				((u32)0x000000FF)        /*!< Enable Broadcast addressing  */    

/*******************  Bit definition for I2C_OAR register  *******************/
#define  I2C_OAR_BC        				((u32)0x00000001)        /*!< Enable Broadcast addressing  */    
#define  I2C_OAR_ADDR      				((u32)0x000000FE)        /*!< Enable Broadcast addressing  */ 

/*******************  Bit definition for I2C_CCR register  *******************/
#define  I2C_CCR_MASK      				((u32)0x000000FF)        /*!<  */
#define  I2C_CCR_PSC0      				((u32)0x00000003)        /*!< System clock division factor bit0  */
#define  I2C_CCR_PSC1      				((u32)0x00000080)        /*!< System clock division factor bit1  */
#define  I2C_CCR_ACK       				((u32)0x00000004)        /*!< ACK generation (slave mode) */
#define  I2C_CCR_SI        				((u32)0x00000008)        /*!< Interrupt status */
#define  I2C_CCR_STOP      				((u32)0x00000010)        /*!< STOP generation (master mode) */
#define  I2C_CCR_STAR      				((u32)0x00000020)        /*!< START generation */
#define  I2C_CCR_EN        				((u32)0x00000040)        /*!< Peripheral enable */
/******************************************************************************/
/*                                                                            */
/*      Universal Asynchronous Receiver Transmitter (UART)       */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for UART_BR register  *******************/
#define  UART_DR_DR               ((u32)0x01FF)               /*!< BR[8:0] bits (Receiver Transmitter Buffer value) */

/******************  Bit definition for UART_CR register  *******************/
#define  UART_CR_WP               ((u32)0x00000007)           /*!< MODE[2:0] bits (ģʽѡ) */
#define  UART_CR_STOP             ((u32)0x00000018)           /*!< STOP[1:0] bits (ֹͣλѡ) */
#define  UART_CR_PS               ((u32)0x00000020)           /*!< żУ鷽ʽ */
#define  UART_CR_LPB              ((u32)0x00000040)           /*!< ģʽ */
#define  UART_CR_EN               ((u32)0x00000080)           /*!< ʷʹ */
#define  UART_CR_RE               ((u32)0x00000100)           /*!< ݽʹ */
#define  UART_CR_RXP              ((u32)0x00010000)           /*!< ݽռԿ */
#define  UART_CR_TXP              ((u32)0x00020000)           /*!< ݷͼԿ */
#define  UART_CR_SLME             ((u32)0x00100000)           /*!< OneWireģʽʹ */
#define  UART_CR_SLDS             ((u32)0x00200000)           /*!< OneWireģʽշ */

/******************  Bit definition for UART_BRR register  *******************/
#define  UART_BRR_BR              ((u32)0x0000FFFF)               /*!< BRR[15:0] bits () */

/******************  Bit definition for UART_IE register  *******************/
#define  UART_IE_RXNEI            ((u32)0x00000001)        /*!< ջзǿжλ */
#define  UART_IE_RXHFI            ((u32)0x00000002)        /*!< ջажλ */
#define  UART_IE_RXFI             ((u32)0x00000004)        /*!< ջȫжλ */
#define  UART_IE_RXCOTI           ((u32)0x00000008)        /*!< ջճʱжλ */
#define  UART_IE_IDLEI            ((u32)0x00000010)        /*!< гʱжλ */
#define  UART_IE_PEI              ((u32)0x00000020)        /*!< żУжλ */      
#define  UART_IE_FEI              ((u32)0x00000040)        /*!< ֡жλ */
#define  UART_IE_OVRI             ((u32)0x00000080)        /*!< ջжλ */    
#define  UART_IE_TXEI             ((u32)0x00000100)        /*!< ͻȫжλ */         
#define  UART_IE_TXHI             ((u32)0x00000200)        /*!< ͻажλ */       
#define  UART_IE_TXFI             ((u32)0x00000400)        /*!< ͻȫжλ */   
#define  UART_IE_TXOI             ((u32)0x00000800)        /*!< ȫжλ */  


/******************  Bit definition for UART_SR register  *******************/
#define  UART_SR_RXNE             ((u32)0x00000001)        /*!< ջзǿжϱʶλ */
#define  UART_SR_RXHF             ((u32)0x00000002)        /*!< ջажϱʶλ */
#define  UART_SR_RXF              ((u32)0x00000004)        /*!< ջȫжϱʶλ */
#define  UART_SR_RXCOT            ((u32)0x00000008)        /*!< ջճʱжϱʶλ */
#define  UART_SR_IDLE             ((u32)0x00000010)        /*!< гʱжϱʶλ */
#define  UART_SR_PE               ((u32)0x00000020)        /*!< żУжϱʶλ */      
#define  UART_SR_FE               ((u32)0x00000040)        /*!< ֡жϱʶλ */
#define  UART_SR_OVR              ((u32)0x00000080)        /*!< ջжϱʶλ */    
#define  UART_SR_TXE              ((u32)0x00000100)        /*!< ͻȫжϱʶλ */         
#define  UART_SR_TXHE             ((u32)0x00000200)        /*!< ͻажϱʶλ */       
#define  UART_SR_TXF              ((u32)0x00000400)        /*!< ͻȫжϱʶλ */   
#define  UART_SR_TXO              ((u32)0x00000800)        /*!< ȫжϱʶλ */  

/******************  Bit definition for UART_TO register  *******************/
#define  UART_TO_TO               ((u32)0xFF)               /*!< TO[8:0] bits (ճʱʱĴλΪ) */

/******************  Bit definition for UART_TXFR register  *******************/
#define  UART_TXFR_TXFR           ((u32)0xFFFFFFFF)        /*!< TXFR[31:0] bits (Ͷиλ) */

/******************  Bit definition for UART_RXFR register  *******************/
#define  UART_RXFR_RXFR           ((u32)0xFFFFFFFF)        /*!< RXFR[31:0] bits (նиλ) */ 

/******************  Bit definition for UART_IMCR register  *******************/
#define  UART_IMCR_IRE            ((u32)0x00000001)        /*!<⹦ʹܿ */
#define  UART_IMCR_IRPN           ((u32)0x00000002)        /*!<ⷢͼԿ */
#define  UART_IMCR_IRBD           ((u32)0x00000030)        /*!<IRBD[1:0]ѡ */
#define  UART_IMCR_IDD            ((u32)0x00000800)        /*!<λ */
#define  UART_IMCR_ISWC           ((u32)0x000F0000)        /*!<ISWC[3:0] ʼλ */  

/******************  Bit definition for UART_IRPWMC register  *******************/
#define  UART_IMDCR_DUTY          ((u32)0x00000FFF)        /*!< PWMC[11:0] bits (ռձȿ) */

/******************************************************************************/
/*                                                                            */
/*                        Independent BEEP (BEEP)                         */
/*                                                                            */
/******************************************************************************/
#define  BEEP_HCR_BEEPE						((u32)0x00000001)       /*!< Enable BEEP High Sink       */
#define  BEEP_CR_EN               ((u32)0x00000001)       /*!< Enable BEEP        */
#define  BEEP_CR_PSC              ((u32)0x0000003E)       /*!< BEEP Clock prescaler        */
#define  BEEP_CR_DIV              ((u32)0x000000C0)       /*!<  BEEP Clock divider       */

/*******************  Bit definition for CMP_CR1 register  ********************/
#define CMP_CR1_EN                ((u32)0x00000001)          /*!< Comparator /Op Amp Enable */
#define CMP_CR1_CRS               ((u32)0x00000002)          /*!< Comparator Output when Positive input is greater than negative input */
#define CMP_CR1_CPS               ((u32)0x0000000C)          /*!< Comparator Positive input source Select */
#define CMP_CR1_DFC               ((u32)0x00000070)          /*!< Comparator Digital filter sampling rate Set */
#define CMP_CR1_CPMS              ((u32)0x00000080)          /*!< Comparator High speed mode */
#define CMP_CR1_OPC               ((u32)0x00000100)          /*!< Comparator Output polarity selection */

/*******************  Bit definition for CMP_CR2 register  ********************/
#define CMP_CR2_MODE              ((u32)0x00000001)          /*!< Enable Operational amplifier mode */
#define CMP_CR2_TME               ((u32)0x00000002)          /*!< Enable Operational amplifier mode */
#define CMP_CR2_TRIM              ((u32)0x000001F0)          /*!< Enable Operational amplifier mode */
#define CMP_CR2_KEY               ((u32)0xFFFF0000)          /*!< Enable Operational amplifier mode */

/********************  Bit definition for CMP_IE register  ********************/
#define CMP_IE_COF                ((u32)0x00000001)          /*!< Comparator output falling edge trigger interrupt enable */
#define CMP_IE_COR                ((u32)0x00000002)          /*!< Comparator output rising edge trigger interrupt enable */
#define CMP_IE_COFW               ((u32)0x00000004)          /*!< Comparator output falling edge trigger interrupt enable */
#define CMP_IE_CORW               ((u32)0x00000008)          /*!< Comparator output rising edge trigger interrupt enable */

/********************  Bit definition for CMP_SR register  ********************/
#define CMP_SR_COF                ((u32)0x00000001)          /*!< Comparator output falling edge trigger interrupt enable */
#define CMP_SR_COR                ((u32)0x00000002)          /*!< Comparator output rising edge trigger interrupt enable */
#define CMP_SR_COFW               ((u32)0x00000004)          /*!< Comparator output falling edge trigger interrupt enable */
#define CMP_SR_CORW               ((u32)0x00000008)          /*!< Comparator output rising edge trigger interrupt enable */

/********************  Bit definition for CMP_CR3 register  ********************/
#define CMP_CR3_DELAY             ((u32)0x000003FF) 

/******************************************************************************/
/*                                                                            */
/*                        OPA													                         */
/*                                                                            */
/******************************************************************************/
/********************  Bit definition for OPA_CR1 register  ********************/
#define OPA_CR1_EN                ((u32)0x00000001)          /*!< Comparator /Op Amp Enable */
#define OPA_CR1_OPS               ((u32)0x0000000C)          /*!< Comparator Positive input source Select */
#define OPA_CR1_OPMS              ((u32)0x00000080)          /*!< Comparator High speed mode */

/*******************  Bit definition for OPA_CR2 register  ********************/
#define OPA_CR2_MODE              ((u32)0x00000001)          /*!< Enable Operational amplifier mode */
#define OPA_CR2_TME               ((u32)0x00000002)          /*!< Enable Operational amplifier mode */
#define OPA_CR2_TRIM              ((u32)0x000001F0)          /*!< Enable Operational amplifier mode */
#define OPA_CR2_KEY               ((u32)0xFFFF0000)          /*!< Enable Operational amplifier mode */

/******************************************************************************/
/*                                                                            */
/*                        7SEG LED Display Interface (LED)                   */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for LED_CR1 register  ********************/
#define LED_CR1_EN                ((u32)0x00000001)          /*!< Peripheral enable */
#define LED_CR1_DUTY              ((u32)0x00000006)          /*!< Select Number of LED displayed in turn  */
#define LED_CR1_IE                ((u32)0x00000008)          /*!< Display completion interrupt */

/*******************  Bit definition for LED_PSC register  ********************/
#define LED_PSC_PSC               ((u32)0x000000FF)          /*!< CLOCK Prescaler factor */

/*******************  Bit definition for LED_DR0 register  ********************/
#define LED_DR0_DR                ((u32)0x000000FF)          /*!< Data0 Register */

/*******************  Bit definition for LED_DR1 register  ********************/
#define LED_DR1_DR                ((u32)0x000000FF)          /*!< Data1 Register */

/*******************  Bit definition for LED_DR2 register  ********************/
#define LED_DR2_DR                ((u32)0x000000FF)          /*!< Data2 Register */

/*******************  Bit definition for LED_DR3 register  ********************/
#define LED_DR3_DR                ((u32)0x000000FF)          /*!< Data3 Register */

/*******************  Bit definition for LED_CR2 register  ********************/
#define LED_CR2_SCAN              ((u32)0x000000FF)          /*!< LED Display Time */
#define LED_CR2_SW                ((u32)0x0000FF00)          /*!< LED Turn Time */

/*******************  Bit definition for LED_SR register  ********************/
#define LED_SR_SCANF              ((u32)0x00000001)          /*!< LED Display Flnish */

/******************************************************************************/
/*                                                                            */
/*                        7SEG LED Display Interface (LED)                   */
/*                                                                            */
/******************************************************************************/
/******************************************************************************/
/*                                                                            */
/*                      IFMC Registers                      */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for IFMC_CR register  ******************/
#define  IFMC_CR_STAR             ((u32)0x00000001)        /*!< FLASH */
#define  IFMC_CR_CMD              ((u32)0x00000006)        /*!< FLASH */
#define  IFMC_CR_WAIT             ((u32)0x000000E0)        /*!< FLASHǱ */
#define  IFMC_CR_MODE             ((u32)0x00000100)        /*!< FLASHдʷʽ */
#define  IFMC_CR_DE               ((u32)0x00000800)        /*!< FLASHʹ */
#define  IFMC_CR_AINC             ((u32)0x00002000)        /*!< FLASHַԶ */
#define  IFMC_CR_KEY1             ((u32)0xADEB0000)        /*!< FLASHд*/
#define  IFMC_CR_KEY2             ((u32)0xC5AE0000)        /*!< FLASHûϢд*/

/*******************  Bit definition for IFMC_SR register  ******************/
																																								
#define  IFMC_SR_WC               ((u32)0x00000001)        /*!< д */
#define  IFMC_SR_PEC              ((u32)0x00000002)        /*!<  */
#define  IFMC_SR_CERR             ((u32)0x00000010)        /*!< FLASH־ */
#define  IFMC_SR_AERR             ((u32)0x00000040)        /*!< FLASHַ־ */

/*******************  Bit definition for IFMC_IE register  ******************/
																																								
#define  IFMC_IE_WCIE             ((u32)0x00000001)        /*!< джʹ */
#define  IFMC_IE_PECIE            ((u32)0x00000002)        /*!< жʹ  */
#define  IFMC_IE_CERIE            ((u32)0x00000010)        /*!< FLASHжʹ */
#define  IFMC_IE_AERIE            ((u32)0x00000040)        /*!< FLASHַжʹ */

/*******************  Bit definition for IFMC_AR register  *******************/
#define  IFMC_AR_AR               ((u32)0x0000FFFC)        /*!< Flash Address */

/*******************  Bit definition for IFMC_DR register  *******************/
#define  IFMC_DR_DR               ((u32)0xFFFFFFFF)        /*!< Flash Address */

/*******************  Bit definition for IFMC_PSC register  *******************/
#define  IFMC_PSC_PSC             ((u32)0x0000000F)        /*!< Flash Address */

/*******************  Bit definition for IFMC_BSR register  *******************/
#define  IFMC_BSR_BSR             ((u32)0x00000001)        /*!< Boot status */

/*******************  Bit definition for IFMC_RPSR register  *******************/
#define  IFMC_RPSR_RPSR           ((u32)0x00000001)        /*!< Data protection status */

/**
  * @}
  */
	

#ifdef USE_STDPERIPH_DRIVER
  #include "PT32x031x_conf.h"
#endif

/** @addtogroup Exported_macro
  * @{
  */
/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_H */

/**
  * @}
  */
/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
