/**
  ******************************************************************************
  * @file    PT32x031x_adc.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   This file contains all the functions prototypes for the ADC firmware 
  *          library
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_ADC_H
#define __PT32x031x_ADC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup ADC
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  ADC Init structure definition
  */
  
typedef struct
{
	u32 ADC_Prescaler;									/*!< Specifies the ADC prescaler,
																						 This parameter can be a value of @ref ADC_Prescaler */

	u32 ADC_Mode;												/*!< Specifies the ADC mode,
																						 This parameter can be a value of @ref ADC_Mode */

	u32 ADC_TriggerSource;							/*!< Specifies the ADC trigger source selection,
																						 This parameter can be a value of @ref ADC_TriggerSource */

	u32 ADC_TimerTriggerSource;					/*!< Specifies the ADC timing trigger source selection,
																						 This parameter can be a value of @ref ADC_TimerTriggerSource */

	u32 ADC_Align;											/*!< Specifies the ADC ALIGN,
																						 This parameter can be a value of @ref ADC_Align */

	u32 ADC_Channel;										/*!< Specifies the ADC channel selection,
																						 This parameter can be a value of @ref ADC_Channel */
} ADC_InitTypeDef;


/* Exported constants --------------------------------------------------------*/

/** @defgroup ADC_Exported_Constants
  * @{
  */ 
#define IS_ADC_ALL_PERIPH(PERIPH)                  ((PERIPH) == ADC)


/** @defgroup ADC_Mode
* @{
*/
#define ADC_Mode_Single			                  (ADC_CR1_MODE&0x00000000)
#define ADC_Mode_Continuous	                  (ADC_CR1_MODE&0x00000002)
#define IS_ADC_Mode(SEL)                      (((SEL) == ADC_Mode_Single)||\
															                ((SEL) == ADC_Mode_Continuous))
  
/** @defgroup ADC_Prescaler
  * @{
  */ 
#define ADC_Prescaler_1   (ADC_CR1_PSC&0x00000000)   /*!<  ADC_Prescaler1*/
#define ADC_Prescaler_2   (ADC_CR1_PSC&0x00000100)   /*!<  ADC_Prescaler2 */
#define ADC_Prescaler_4   (ADC_CR1_PSC&0x00000200)   /*!<  ADC_Prescaler4 */
#define ADC_Prescaler_8   (ADC_CR1_PSC&0x00000300)   /*!<  ADC_Prescaler8 */
#define IS_ADC_Prescaler(SEL) (((SEL) == ADC_Prescaler_1)  ||\
				                         ((SEL) == ADC_Prescaler_2) ||\
				                         ((SEL) == ADC_Prescaler_4) ||\
				                         ((SEL) == ADC_Prescaler_8))

/** @defgroup ADC_TriggerSource
* @{
*/
#define ADC_TriggerSource_Software       (ADC_CR1_TRIGS&0x00000000)
#define ADC_TriggerSource_Timer          (ADC_CR1_TRIGS&0x00000004)
#define ADC_TriggerSource_ExternalPin    (ADC_CR1_TRIGS&0x00000008)
#define IS_ADC_TriggerSource(SEL)        (((SEL) == ADC_TriggerSource_Software)||\
																					((SEL) == ADC_TriggerSource_Timer)   ||\
																					((SEL) == ADC_TriggerSource_ExternalPin))
/** @defgroup ADC_TimerTriggerSource
* @{
*/
#define ADC_TimerTriggerSource_TIM0ADC   (ADC_CR1_TIMS&0x00000000)
#define ADC_TimerTriggerSource_TIM1ADC   (ADC_CR1_TIMS&0x00000010)
#define ADC_TimerTriggerSource_TIM2ADC   (ADC_CR1_TIMS&0x00000020)
#define ADC_TimerTriggerSource_TIM3ADC   (ADC_CR1_TIMS&0x00000030)
#define IS_ADC_TimerTriggerSource(SEL)   (((SEL) & ~ADC_CR1_TIMS) == 0 && SEL <= ADC_TimerTriggerSource_TIM3ADC)
																							

/**
  * @}
  */ 

/** @defgroup ADC_data_align 
  * @{
  */ 
  
#define ADC_Align_Right          ((u32)0x00000000)
#define ADC_Align_Left           ADC_CR1_ALIGN

#define IS_ADC_Align(ALIGN) (((ALIGN) == ADC_Align_Right) || \
                                  ((ALIGN) == ADC_Align_Left))
/**
  * @}
  */


/** @defgroup ADC_channels 
  * @{
  */ 
  
#define ADC_Channel_0                              ADC_CR1_CHS_0
#define ADC_Channel_1                              ADC_CR1_CHS_1
#define ADC_Channel_2                              ADC_CR1_CHS_2
#define ADC_Channel_3                              ADC_CR1_CHS_3
#define ADC_Channel_4                              ADC_CR1_CHS_4
#define ADC_Channel_5                              ADC_CR1_CHS_5
#define ADC_Channel_6                              ADC_CR1_CHS_6
#define ADC_Channel_7                              ADC_CR1_CHS_7
#define ADC_Channel_8                              ADC_CR1_CHS_8
#define ADC_Channel_9                              ADC_CR1_CHS_9
#define ADC_Channel_10                             ADC_CR1_CHS_10 
#define ADC_Channel_11                             ADC_CR1_CHS_11 
#define ADC_Channel_12                             ADC_CR1_CHS_12

#define IS_ADC_Channel(CHANNEL)         (((CHANNEL) == ADC_Channel_0) ||\
                                         ((CHANNEL) == ADC_Channel_1) ||\
                                         ((CHANNEL) == ADC_Channel_2) ||\
                                         ((CHANNEL) == ADC_Channel_3) ||\
                                         ((CHANNEL) == ADC_Channel_4) ||\
                                         ((CHANNEL) == ADC_Channel_5) ||\
                                         ((CHANNEL) == ADC_Channel_6) ||\
                                         ((CHANNEL) == ADC_Channel_7) ||\
                                         ((CHANNEL) == ADC_Channel_8) ||\
                                         ((CHANNEL) == ADC_Channel_9) ||\
                                         ((CHANNEL) == ADC_Channel_10)||\
                                         ((CHANNEL) == ADC_Channel_11)||\
                                         ((CHANNEL) == ADC_Channel_12))
/**
  * @}
  */ 
  
/** @defgroup ADC_interrupts_definition 
  * @{
  */ 

#define ADC_IT_EOC                       ADC_CR1_EOCIE
 
#define IS_ADC_IT(IT) ((IT) == ADC_IT_EOC)

#define IS_ADC_GET_IT(IT)    ((IT) == ADC_IT_EOC)                     

#define IS_ADC_CLEAR_IT(IT)  (((IT) != (u32)RESET) && (((IT) & 0xFFFFFBFF) == (u32)RESET))

/**
  * @}
  */ 

/** @defgroup ADC_flags_definition 
  * @{
  */ 
  
#define ADC_FLAG_RDY    ADC_SR_RDY
#define ADC_FLAG_EOC    ADC_SR_EOC
#define IS_ADC_GET_FLAG(FLAG)     (((FLAG) == ADC_FLAG_RDY)   || ((FLAG) == ADC_FLAG_EOC))     
#define IS_ADC_CLEAR_FLAG(FLAG)   ((FLAG) == ADC_FLAG_EOC)

       
#define IS_ADC_ReadyTime(SEL)    ((SEL)<=0xFF)			 
/**
  * @}
  */
  
/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 

/*  Function used to set the ADC configuration to the default reset state *****/


/* Initialization and Configuration functions *********************************/ 


/* This Function is obsolete and maintained for legacy purpose only.
   ADC_PrescalerConfig() function should be used instead */


/* Power saving functions *****************************************************/





/* Channels Configuration functions *******************************************/



/* Interrupts and flags management functions **********************************/

void ADC_Init(ADC_TypeDef* ADCx, ADC_InitTypeDef* ADC_InitStruct);
void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_PrescalerConfig(ADC_TypeDef* ADCx, u32 ADC_ClockMode);
void ADC_TriggerSource(ADC_TypeDef *ADCx, u32 SEL);
void ADC_Mode(ADC_TypeDef* ADCx, u32 SEL);
void ADC_ChannelConfig(ADC_TypeDef* ADCx, u32 ADC_Channel);
void ADC_StartOfConversion(ADC_TypeDef* ADCx);
u16 ADC_GetConversionValue(ADC_TypeDef* ADCx);
void ADC_ITConfig(ADC_TypeDef* ADCx, u32 ADC_IT, FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_ClearFlag(ADC_TypeDef* ADCx, u32 ADC_FLAG);
ITStatus ADC_GetITStatus(ADC_TypeDef* ADCx, u32 ADC_IT);
void ADC_ReadyTimeConfig(ADC_TypeDef *ADCx, u32 ReadyTime);

#ifdef __cplusplus
}
#endif

#endif /*__PT32x031_ADC_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
