/**
  ******************************************************************************
  * @file    PT32x031x_cmp.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  * 
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_CMP_H
#define __PT32x031x_CMP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup Analog comparators and operational amplifiers
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  CMP Init structure definition
  */
  
typedef struct
{                                                         
	u32 CMP_DigitalFilter;                  
	
	u32 CMP_PowerMode;
	
  u32 CMP_OutputPolarity; 
  
  u32 CMP_PositiveInput;	
	
	u32 CMP_InitializationDelayTime;
	
}CMP_InitTypeDef;


/* Exported constants --------------------------------------------------------*/

#define IS_CMP_InitializationDelayTime(SEL) 			((SEL) <= 0x3FF )

/** @defgroup CMPOPA_Exported_Constants
  * @{
  */ 
#define IS_CMP_ALL_PERIPH(PERIPH)   (((PERIPH) == CMP0) || ((PERIPH) == CMP1))

#define IS_CMPOPA_DAC_VALUE(VALUE)  ((VALUE) <= 0x1F)

/** @defgroup CMP_FEFSEL
  * @{
  */ 
#define CMP_CR1_CPS_POSITIVE  ((u32)0x00000000)          /*!< Comparator Positive input From PIN */
#define CMP_CR1_CPS_LDAC  ((u32)0x00000004)          /*!< Comparator Positive input From DAC */
#define CMP_CR1_CPS_BG1V0   ((u32)0x00000008)          /*!< Comparator Positive input From BandGap Voltage */

#define CMP_PositiveInput_CMPxP  CMP_CR1_CPS_POSITIVE  
#define CMP_PositiveInput_LDAC   CMP_CR1_CPS_LDAC  
#define CMP_PositiveInput_BG1V   CMP_CR1_CPS_BG1V0  
#define IS_CMP_PositiveInput(SOURCE)  (((SOURCE) == CMP_PositiveInput_CMPxP) ||\
				                        ((SOURCE) == CMP_PositiveInput_LDAC) ||\
				                        ((SOURCE) == CMP_PositiveInput_BG1V))
/**
  * @}
  */ 
#define CMP_OutputPolarity_Normal 			 (CMP_CR1_OPC&0x000)
#define CMP_OutputPolarity_Inverted			 (CMP_CR1_OPC&0x100)
#define IS_CMP_OutputPolarity(SEL)       ((SEL==CMP_OutputPolarity_Normal)||\
																					(SEL==CMP_OutputPolarity_Inverted))

/** @defgroup Digital filtering sampling times
  * @{
  */ 
#define CMP_DigitalFilter_None                       (CMP_CR1_DFC&0x00)   /*!<  Synchronous clock mode no divided*/
#define CMP_DigitalFilter_X2                         (CMP_CR1_DFC&0x10)     /*!<  Synchronous clock mode divided by 2 */
#define CMP_DigitalFilter_X4                         (CMP_CR1_DFC&0x20)     /*!<  Synchronous clock mode divided by 2 */
#define CMP_DigitalFilter_X8                         (CMP_CR1_DFC&0x30)     /*!<  Synchronous clock mode divided by 2 */
#define CMP_DigitalFilter_X16                        (CMP_CR1_DFC&0x40)    /*!<  Synchronous clock mode divided by 2 */
#define CMP_DigitalFilter_X32                        (CMP_CR1_DFC&0x50)    /*!<  Synchronous clock mode divided by 2 */
#define CMP_DigitalFilter_X64                        (CMP_CR1_DFC&0x60)    /*!<  Synchronous clock mode divided by 2 */
#define IS_CMP_DigitalFilter(TIMES)  (((TIMES) == CMP_DigitalFilter_None) ||\
				                        ((TIMES) == CMP_DigitalFilter_X2) ||\
				                        ((TIMES) == CMP_DigitalFilter_X4) ||\
				                        ((TIMES) == CMP_DigitalFilter_X8) ||\
				                        ((TIMES) == CMP_DigitalFilter_X16) ||\
				                        ((TIMES) == CMP_DigitalFilter_X32) ||\
				                        ((TIMES) == CMP_DigitalFilter_X64))
																
/** @defgroup CMP_power_mode_selection
  * @{
  */
#define CMP_PowerMode_LowPower	 (CMP_CR1_CPMS&0x00)
#define CMP_PowerMode_HighSpeed  (CMP_CR1_CPMS&0x80)
#define IS_CMP_PowerMode(SEL) 	 ((SEL==CMP_PowerMode_HighSpeed)||(SEL==CMP_PowerMode_LowPower))

/**
  * @}
  */ 

/** @defgroup CMP_interrupts_definition 
  * @{
  */ 

#define CMP_IT_FALL                                 CMP_IE_COF
#define CMP_IT_RISE                                 CMP_IE_COR
#define CMP_IT_FALL_WAKE                            CMP_IE_COFW
#define CMP_IT_RISE_WAKE                            CMP_IE_CORW				
 
#define IS_CMP_IT(IT)  (((IT&(u32)0xFFFFFFF0)==0&&(IT!=0)))

/**
  * @}
  */ 

/** @defgroup CMP_flags_definition 
  * @{
  */ 
  
#define CMP_FLAG_FALL                                 CMP_SR_COF
#define CMP_FLAG_RISE                                 CMP_SR_COR
#define CMP_FLAG_FALL_WAKE                            CMP_SR_COFW
#define CMP_FLAG_RISE_WAKE                            CMP_SR_CORW				
  
#define IS_CMP_GET_FLAG(FLAG) (((FLAG) == CMP_FLAG_FALL) ||\
				                       ((FLAG) == CMP_FLAG_RISE) ||\
				                       ((FLAG) == CMP_FLAG_FALL_WAKE) ||\
				                       ((FLAG) == CMP_FLAG_RISE_WAKE))
															 
#define IS_CMP_CLEAR_FLAG(FLAG)  (((FLAG) != (u32)RESET) && (((FLAG) & 0xFFFFFFF0) == (u32)RESET))															 

#define IS_CMP_TrimValue(value)  ((value) <= 0x1F)
/**
  * @}
  */
  

  
/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 
void CMP_Init(CMP_TypeDef* CMPx, CMP_InitTypeDef* CMP_InitStruct);
void CMP_Cmd(CMP_TypeDef* CMPx, FunctionalState NewState);
void CMP_ModeConfig(CMP_TypeDef* CMPx, FunctionalState NewState);
void CMP_SetInitDelayValue(CMP_TypeDef* CMPx, u32 CMPOPA_InitaDelay);
void CMP_ITConfig(CMP_TypeDef* CMPx, u32 CMP_IT, FunctionalState NewState);
FlagStatus CMP_GetFlagStatus(CMP_TypeDef* CMPx, u32 CMP_FLAG);
void CMP_ClearFlag(CMP_TypeDef* CMPx, u32 CMP_FLAG);
void CMP_TrimMode(CMP_TypeDef* CMPx,FunctionalState NewState);
void CMP_TrimValue(CMP_TypeDef* CMPx,u32 value);
/*  Function used to set the ADC configuration to the default reset state *****/


/* Initialization and Configuration functions *********************************/ 



/* Power saving functions *****************************************************/





/* Channels Configuration functions *******************************************/



/* Interrupts and flags management functions **********************************/


#ifdef __cplusplus
}
#endif

#endif /*__PT32x031_CMP_OPA_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
