/**
  ******************************************************************************
  * @file    PT32x031x_crc.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    2023/12/1
  * @brief   This file contains all the functions prototypes for the CRC firmware 
  *          library.
  ******************************************************************************
  * @attention
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_CRC_H
#define __PT32x031x_CRC_H

#ifdef __cplusplus
 extern "C" {
#endif

/*!< Includes ----------------------------------------------------------------*/
#include "PT32x031x.h"

/** @defgroup CRC_InitTypeDef
* @{
*/
typedef struct
{
	u32 CRC_Input;											/*!< Specifies the CRC input,
																					 This parameter can be a value of @ref CRC_Input */

	u32 CRC_InputBitSequenceReversal;		/*!< Specifies the CRC input Bit Sequence Reversal,
																					 This parameter can be a value of @ref CRC_InputBitSequenceReversal */

	u32 CRC_InputByteSequenceReversal;	/*!< Specifies the CRC input Byte Sequence Reversal,
																					 This parameter can be a value of @ref CRC_InputByteSequenceReversal */

	u32 CRC_OutputBitSequenceReversal;	/*!< Specifies the CRC Output Bit Sequence Reversal,
																				   This parameter can be a value of @ref CRC_OutputBitSequenceReversal */

	u32 CRC_Seed;												/*!< Specifies the CRC Seed,
																					 This parameter can be a value of @ref CRC_Seed */

	u32 CRC_Poly;												/*!< Specifies the CRC Poly,
																					 This parameter can be a value of @ref CRC_Poly */

} CRC_InitTypeDef;

/** @defgroup CRC_Input
* @{
*/
#define CRC_Input_8b		                     (CRC_CR_CIS&0x00000000)	       //!< CRC DataIn Width 8bit
#define CRC_Input_16b		                     (CRC_CR_CIS&0x00000004)	       //!< CRC DataIn Width 16bit
#define IS_CRC_Input(SEL)		((SEL == CRC_Input_8b) || \
								 (SEL == CRC_Input_16b))

/** @defgroup CRC_InputBitSequenceReversal
* @{
*/
#define CRC_InputBitSequenceReversal_Disable		    	(CRC_CR_CISN&0x00000000)
#define CRC_InputBitSequenceReversal_Enable		        (CRC_CR_CISN&0x00000008)
#define IS_CRC_InputBitSequenceReversal(SEL)		((SEL == CRC_InputBitSequenceReversal_Disable) || \
													 (SEL == CRC_InputBitSequenceReversal_Enable))

/** @defgroup CRC_InputByteSequenceReversal
* @{
*/
#define CRC_InputByteSequenceReversal_Disable		    		(CRC_CR_CBN&0x00000000)
#define CRC_InputByteSequenceReversal_Enable		        (CRC_CR_CBN&0x00000010)
#define IS_CRC_InputByteSequenceReversal(SEL)		((SEL == CRC_InputByteSequenceReversal_Disable) || \
													 (SEL == CRC_InputByteSequenceReversal_Enable))

/** @defgroup CRC_OutputBitSequenceReversal
* @{
*/
#define CRC_OutputBitSequenceReversal_Disable		    		(CRC_CR_COSN&0x00000000)
#define CRC_OutputBitSequenceReversal_Enable		        (CRC_CR_COSN&0x00000020)
#define IS_CRC_OutputBitSequenceReversal(SEL)		((SEL == CRC_OutputBitSequenceReversal_Disable) || \
													 (SEL == CRC_OutputBitSequenceReversal_Enable))

/** @defgroup CRC_Seed
* @{
*/
#define IS_CRC_Seed(SEL)	((SEL) <= 0xFFFF)

/** @defgroup CRC_Poly
* @{
*/
#define CRC_CCITT16	    0x00001021           //!< 0x1021
#define CRC_IBM16				0x00008005           //!< 0x8005
#define	IS_CRC_Poly(SEL)	((SEL) == CRC_CCITT16 || (SEL) == CRC_IBM16)

/*! function declaration and definition*/
void CRC_Init(CRC_InitTypeDef *CRC_InitStruct);
void CRC_StructInit(CRC_InitTypeDef *CRC_InitStruct);
void CRC_Cmd(FunctionalState NewState);
void CRC_ResetDout(void);
u16 CRC_CalculateCRC(u16 CRC_Data);
u16 CRC_CalculateBlockCRC(u16 pBuffer[], u32 BufferLength);
u16 CRC_GetCRC(void);
void CRC_Seed(u16 Seed);
void CRC_Poly(u16 Poly);

#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_CRC_H */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
