/**
  ******************************************************************************
  * @file    PT32x031x_i2c.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/12/1
  * @brief   This file contains all the functions prototypes for the I2C firmware
  *          library
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_I2C_H
#define __PT32x031x_I2C_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"


/** @defgroup IS_I2C_Event
  * @{
  */
#define  I2C_Event_Stop								 ((u8)0x00)
#define  I2C_Event_Start							 ((u8)0x01)
#define  I2C_Event_Restart						 ((u8)0x02)
#define  IS_I2C_Event(SEL)  					 (((SEL)==I2C_Event_Stop) || ((SEL)==I2C_Event_Start) || ((SEL)==I2C_Event_Restart))

/**
  * @brief  I2C Init structure definition
  */

typedef struct
{
  u32 I2C_Broadcast;    /*!< Specifies the I2C mode.
                                         This parameter can be a value of @ref I2C_mode*/

  u32 I2C_OwnAddress;          /*!< Specifies the device own address 1.
                                         This parameter can be a 7-bit or 10-bit address*/

  u32 I2C_Acknowledge;          /*!< Enables or disables the acknowledgement.
                                         This parameter can be a value of @ref I2C_acknowledgement*/

  u32 I2C_Prescaler;            /*!< */
	
}I2C_InitTypeDef;

/** @defgroup I2C_broadcast_state
  * @{
  */
#define  I2C_Broadcast_Enable			 		I2C_OAR_BC
#define  I2C_Broadcast_Disable				(I2C_OAR_BC&0x00000000)
#define  IS_I2C_Broadcast(SEL)				(((SEL) == I2C_Broadcast_Enable) || ((SEL) == I2C_Broadcast_Disable))

/** @defgroup I2C_acknowledge_state
  * @{
  */
#define  I2C_Acknowledge_Enable			I2C_CR_ACK
#define  I2C_Acknowledge_Disable		(I2C_CR_ACK&0x00000000)
#define  IS_I2C_Acknowledge(SEL)		(((SEL) == I2C_Acknowledge_Enable) || ((SEL) == I2C_Acknowledge_Disable))

/* Exported constants --------------------------------------------------------*/

/** @defgroup I2C_FLAG
  * @{
  */
#define I2C_FLAG_Stop 			  			(I2C_SR_SR&0x00)	/* ϳһֹͣź	*/
#define I2C_FLAG_StartOk 						(I2C_SR_SR&0x08)	/* ʼźŷ */
#define I2C_FLAG_ReStartOk 					(I2C_SR_SR&0x10)	/* ظʼźŷ */
#define I2C_FLAG_MASGetAckW 				(I2C_SR_SR&0x18)	/*  ַַϣ յ ACK  */
#define I2C_FLAG_MASGetNackW 				(I2C_SR_SR&0x20)	/*  ַַϣ յ NACK */
#define I2C_FLAG_MDSGetAck 					(I2C_SR_SR&0x28)	/*  ַϣ յ ACK  */
#define I2C_FLAG_MDSGetNack 				(I2C_SR_SR&0x30)	/*  ַϣ յ NACK */
#define I2C_FLAG_MArbitrationlost 	(I2C_SR_SR&0x38)	/*  ٲʧ */
#define I2C_FLAG_MASGetAckR 				(I2C_SR_SR&0x40)	/*  ַַϣ յ ACK  */
#define I2C_FLAG_MASGetNackR 				(I2C_SR_SR&0x48)	/*  ַַϣ յ NACK */
#define I2C_FLAG_MDGSendAck 				(I2C_SR_SR&0x50)	/*  ֽϣ  ACK  */
#define I2C_FLAG_MDGSendNack 				(I2C_SR_SR&0x58)	/*  ֽϣ  NACK */

#define I2C_FLAG_SAGSendAckW 				(I2C_SR_SR&0x60)	/* ӻ ַֽϣ  ACK */
#define I2C_FLAG_SALAGSendAckW 			(I2C_SR_SR&0x68)	/* ӻ ٲʧתĴӻ ַֽϣ  ACK */
#define I2C_FLAG_SBCAGSendAck 			(I2C_SR_SR&0x70)	/* ӻ 㲥ַֽϣ  ACK */
#define I2C_FLAG_SALBCAGSendAck 		(I2C_SR_SR&0x78)	/* ӻ ٲʧתĴӻ㲥ַֽϣ  ACK */
#define I2C_FLAG_SDGSendAck 				(I2C_SR_SR&0x80)	/* ӻ ֽϣ  ACK */
#define I2C_FLAG_SDGSendNack 				(I2C_SR_SR&0x88)	/* ӻ ֽϣ  NACK */
#define I2C_FLAG_SBCDGSendAck 			(I2C_SR_SR&0x90)	/* ӻ 㲥ֽϣ  ACK */
#define I2C_FLAG_SBCDGSendNack 			(I2C_SR_SR&0x98)	/* ӻ 㲥ֽϣ  NACK */
#define I2C_FLAG_SDGGSRS 						(I2C_SR_SR&0xA0)	/* ӻ ֽϣ յֹͣźŻظʼź */
#define I2C_FLAG_SAGSendAckR 				(I2C_SR_SR&0xA8)	/* ӻ ַֽϣ  ACK */
#define I2C_FLAG_SALAGSendAckR 			(I2C_SR_SR&0xB0)	/* ӻ ٲʧתĴӻ,ַֽϣ  ACK */
#define I2C_FLAG_SDSReadAck 				(I2C_SR_SR&0xB8)	/* ӻ ַϣ յ ACK */
#define I2C_FLAG_SDSReadNack 				(I2C_SR_SR&0xC0)	/* ӻ ַϣ յ NACK */
#define I2C_FLAG_SDSSAGSRS 					(I2C_SR_SR&0xC8)	/* ӻ ֽϣ  ACK 󡢽յֹͣźŻظʼź */
#define I2C_FLAG_IDLE 							(I2C_SR_SR&0xF8)	/* ߿*/
#define IS_I2C_StatusFlag(SEL) 	 (((SEL)& ~I2C_SR_SR) == 0 && ((SEL)<=I2C_FLAG_IDLE))

/** @defgroup I2C_Exported_Constants
  * @{
  */

#define I2CMASTER           0x01
#define I2CSLAVE            0x02

#define IS_I2C_ALL_PERIPH(PERIPH)       (((PERIPH) == I2C0) || \
                                        ((PERIPH) == I2C1))
                                         

/** @defgroup I2C_acknowledgement
  * @{
  */

#define I2C_Ack_Enable                  I2C_CR_ACK
#define I2C_Ack_Disable                 I2C_CCR_ACK

/**
  * @}
  */
	
/** @defgroup I2C_Prescaler
  * @{
  */

#define I2C_Prescaler_DIV960                 ((u32)0x00000080)
#define I2C_Prescaler_DIV256                 ((u32)0x00000000)
#define I2C_Prescaler_DIV244                 ((u32)0x00000001)
#define I2C_Prescaler_DIV192                 ((u32)0x00000002)
#define I2C_Prescaler_DIV160                 ((u32)0x00000003)
#define I2C_Prescaler_DIV120                 ((u32)0x00000081)
#define I2C_Prescaler_DIV60                  ((u32)0x00000082)


#define IS_I2C_Prescaler_DIV(DIV)         (((DIV) == I2C_Prescaler_DIV60)  || \
                                          ((DIV) == I2C_Prescaler_DIV120) || \
                                          ((DIV) == I2C_Prescaler_DIV160) || \
                                          ((DIV) == I2C_Prescaler_DIV192) || \
                                          ((DIV) == I2C_Prescaler_DIV244) || \
                                          ((DIV) == I2C_Prescaler_DIV256) || \
                                          ((DIV) == I2C_Prescaler_DIV960))
/**
  * @}
  */



/** @defgroup I2C_own_address1
  * @{
  */

#define IS_I2C_AddressValue(ADDRESS)   ((ADDRESS) <= (u32)0x0000007F)
/**
  * @}
  */


/** @defgroup I2C_slave_address
  * @{
  */

/** @defgroup I2C_interrupts_definition 
  * @{
  */

#define I2C_IT_IS                      I2C_CR_SI

#define IS_I2C_CONFIG_IT(IT)           (((IT) == I2C_IT_IS))

/**
  * @}
  */

/** @defgroup I2C_flags_definition 
  * @{
  */

#define  I2C_FLAG_IS                  I2C_CR_SI


#define IS_I2C_CLEAR_FLAG(FLAG)       (((FLAG) == I2C_FLAG_IS))      

#define IS_I2C_GET_FLAG(FLAG)         (((FLAG) == I2C_FLAG_IS)) 
/**
  * @}
  */


#ifdef __cplusplus
}
#endif
void I2C_Init(I2C_TypeDef* I2Cx, I2C_InitTypeDef* I2C_InitStruct);
void I2C_StructInit(I2C_InitTypeDef* I2C_InitStruct);
void I2C_Cmd(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_SendData(I2C_TypeDef *I2Cx, u8 Data);
void I2C_SendAddress(I2C_TypeDef *I2Cx, u8 Data);
void I2C_GenerateEvent(I2C_TypeDef *I2Cx, u8 Event, FunctionalState NewState);
void I2C_AcknowledgeConfig(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_SendData(I2C_TypeDef* I2Cx, u8 Data);
u8 I2C_ReceiveData(I2C_TypeDef* I2Cx);
FlagStatus I2C_GetFlagStatus(I2C_TypeDef* I2Cx, u16 I2C_FLAG);

#endif /*__PT32x031_I2C_H */

/**
  * @}
  */

/**
  * @}
  */

/************************   *****END OF FILE****/
