/**
  ******************************************************************************
  * @file    PT32x031x_ifmc.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031_IFMC_H
#define __PT32x031_IFMC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

#define  IFMC_CR_CMD_PAGE  ((u32)0x00000002)        /*!< FLASHҳ */
#define  IFMC_CR_CMD_CHIP  ((u32)0x00000006)        /*!< FLASHȫƬ */
/** @addtogroup FLASH
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  FLASH Status
  */ 
typedef enum
{	
  IFMC_WRITE_END=1,
  IFMC_ERASE_END,
  IFMC_PROTECT_ERASE_END,
  IFMC_BUSY,
  IFMC_CMD_ERR,
  IFMC_KEY_ERR,
  IFMC_ADDR_ERR,
  IFMC_COMPLETE,
  IFMC_TIMEOUT
}IFMC_Status;

/* Exported constants --------------------------------------------------------*/
  
/** @defgroup IFMC_Exported_Constants
  * @{
  */ 
  
/** @defgroup IFMC_WAIT 
  * @{
  */ 
#define IFMC_Latency_0                ((uint32_t)0x00000000)  /*!< FLASH Zero Latency cycle */
#define IFMC_Latency_1                IFMC_CR_WAIT       /*!< FLASH One Latency cycle */

#define IS_IFMC_LATENCY(LATENCY) (((LATENCY) == IFMC_Latency_0) || \
                                   ((LATENCY) == IFMC_Latency_1))
/**
  * @}
  */ 

/** @defgroup IFMC_Interrupts 
  * @{
  */
   
#define IFMC_IT_EOPRO                   IFMC_IE_WCIE  /*!< End of programming interrupt source */
#define IFMC_IT_EOPAGEE                 IFMC_IE_PECIE  /*!< End of page erase interrupt source */
#define IFMC_IT_EOPRERENDIE             IFMC_IE_PECIE  /*!< End of protect erase interrupt source */
#define IFMC_IT_CMDER                   IFMC_IE_CERIE  /*!< Command error interrupt source */
#define IFMC_IT_KEYER                   IFMC_IER_KEYERIE  /*!< Key error interrupt source */
#define IFMC_IT_ADER                    IFMC_IE_AERIE   /*!< Address error interrupt source */
#define IS_IFMC_IT(IT) ((((IT) & (uint32_t)0xFFFFFFA8) == 0x00000000) && (((IT) != 0x00000000)))
/**
  * @}
  */ 

/** @defgroup IFMC_Address 
  * @{
  */
#if defined(PT32x031)     /*32K devices */
#define IFMC_PAGE_SIZE    ((uint16_t)0x200)	 /*!< 512B */
#define IFMC_DEV_SIZE       64

#define MAINCODE_START_ADDR  ((uint32_t)0x00000000)
#define MAINCODE_END_ADDR    ((uint32_t)0x00007600) 

#define BOOTCODE_START_ADDR  ((uint32_t)0x00007600)
#define BOOTCODE_END_ADDR    ((uint32_t)0x00007E00)
	 
#define USERINF_START_ADDR   ((uint32_t)0x00007E00)
#define USERINF_END_ADDR     ((uint32_t)0x00008000)
#define IS_IFMC_PROGRAM_ADDRESS(ADDRESS)   ((((ADDRESS) <= MAINCODE_END_ADDR)) || \
                                             (((ADDRESS) >= USERINF_START_ADDR) && ((ADDRESS) <= USERINF_END_ADDR)))
#endif
/**
  * @}
  */
  
/** @defgroup IFMC_Flags 
  * @{
  */ 

#define IFMC_FLAG_WREND                 IFMC_SR_WC     /*!< FLASH дɱ־ */
#define IFMC_FLAG_EREND                 IFMC_SR_PEC     /*!< FLASHɱ־ */
#define IFMC_FLAG_CMDER                 IFMC_SR_CERR     /*!< FLASH־*/
#define IFMC_FLAG_ADER                  IFMC_SR_AERR      /*!< FLASHַ־ */

 
#define IS_IFMC_CLEAR_FLAG(FLAG) ((((FLAG) & (uint32_t)0xFFFFFFA8) == 0x00000000) && ((FLAG) != 0x00000000))

#define IS_IFMC_GET_FLAG(FLAG)  (((FLAG) == IFMC_FLAG_WREND) || \
                                 ((FLAG) == IFMC_FLAG_EREND) || \
                                 ((FLAG) == IFMC_FLAG_CMDER) || \
                                 ((FLAG) == IFMC_FLAG_ADER))
/**
  * @}
  */ 

/** @defgroup IFMC_Timeout_definition 
  * @{
  */ 
#define IFMC_ER_PRG_TIMEOUT         ((uint32_t)0x000B0000)

/**
  * @}
  */ 

/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/

/** 
  * @brief  FLASH Operation Commands.  
  */ 
#define IFMC_OPCMD_PRO   ((uint32_t)0x00000000) 
#define IFMC_OPMOD_RE    ((uint32_t)0x00000000) 
#define IFMC_OPCMD_PERA   IFMC_CR_CMD_PAGE
#define IFMC_OPCMD_MERA   IFMC_ACR_MERA
#define IFMC_OPMOD_WR     IFMC_CR_MODE
#define IFMC_OPSTR_STRT   IFMC_CR_STAR

/* Exported functions ------------------------------------------------------- */
  
/** 
  * @brief  FLASH memory functions that can be executed from FLASH.  
  */  
/* FLASH Interface configuration functions ************************************/
void IFMC_SetLatency(uint32_t IFMC_WAIT);

/* FLASH Memory Programming functions *****************************************/
IFMC_Status IFMC_ErasePage(uint32_t Page_Address);
IFMC_Status IFMC_EraseAllPages(void);
IFMC_Status IFMC_ProgramWord(uint32_t Address, uint32_t Data);

/* FLASH Memory Reading functions *****************************************/
uint32_t IFMC_ReadWord(uint32_t Address);
uint16_t IFMC_ReadHalfWord(uint32_t Address);
uint8_t IFMC_ReadByte(uint32_t Address);

/* FLASH Interrupts and flags management functions **********************************/
void IFMC_ITConfig(uint32_t IFMC_IT, FunctionalState NewState);
FlagStatus IFMC_GetFlagStatus(uint32_t IFMC_FLAG);
void IFMC_ClearFlag(uint32_t IFMC_FLAG);
IFMC_Status IFMC_GetStatus(void);
IFMC_Status IFMC_WaitForLastOperation(uint32_t Timeout);
ProtectStatus System_GetIFMCProtectStatus(void);
  
#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_IFMC_H */

/**
  * @}
  */

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
