/**
  ******************************************************************************
  * @file    PT32x031x_opa.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_OPA_H
#define __PT32x031x_OPA_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup Analog operational amplifiers
  * @{
  */

#define OPA_Trim_KEY  			(u32)((u32)0xACDE<<16)

#define IS_OPA_TrimValue(SEL)  (((SEL)&(u32)0x1F)==0)
/* Exported types ------------------------------------------------------------*/

typedef struct
{
	u32 OPA_PowerMode;
  u32 OPA_PositiveInput;	
}OPA_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup OPA_Exported_Constants
  * @{
  */ 
#define IS_OPA_ALL_PERIPH(PERIPH)                  (((PERIPH) == OPA0) || ((PERIPH) == OPA1))

#define OPA_CR1_OPS_POSITIVE  ((u32)0x00000000)          /*!< Comparator Positive input From PIN */
#define OPA_CR1_OPS_LDAC      ((u32)0x00000004)          /*!< Comparator Positive input From DAC */
#define OPA_CR1_OPS_BG1V0     ((u32)0x00000008)          /*!< Comparator Positive input From BandGap Voltage */

#define OPA_PositiveInput_OPAxP  OPA_CR1_OPS_POSITIVE  
#define OPA_PositiveInput_LDAC   OPA_CR1_OPS_LDAC  
#define OPA_PositiveInput_BG1V   OPA_CR1_OPS_BG1V0  
#define IS_OPA_PositiveInput(SOURCE)  (((SOURCE) == OPA_PositiveInput_OPAxP) ||\
				                        ((SOURCE) == OPA_PositiveInput_LDAC) ||\
				                        ((SOURCE) == OPA_PositiveInput_BG1V))

/** @defgroup OPA_power_mode_selection
  * @{
  */
#define OPA_PowerMode_LowPower	 (OPA_CR1_OPMS&0x00)
#define OPA_PowerMode_HighSpeed  (OPA_CR1_OPMS&0x80)
#define IS_OPA_PowerMode(SEL) 	 ((SEL==OPA_PowerMode_HighSpeed)||(SEL==OPA_PowerMode_LowPower))

/**
  * @}
  */
  

  
/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 
void OPA_Init(OPA_TypeDef* OPAx, OPA_InitTypeDef* OPA_InitStruct);
void OPA_Cmd(OPA_TypeDef* OPAx, FunctionalState NewState);
void OPA_ModeConfig(OPA_TypeDef* OPAx, FunctionalState NewState);
void OPA_TrimMode(OPA_TypeDef* OPAx,FunctionalState NewState);
void OPA_TrimValue(OPA_TypeDef* OPAx,u32 value);

#ifdef __cplusplus
}
#endif

#endif /*__PT32x031_OPA_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
