/**
  ******************************************************************************
  * @file    PT32x031x_PWM.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1 
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031_PWM_H
#define __PT32x031_PWM_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup PWM
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

   
   
/** 
  * @brief  PWM Init Structure definition  
  */ 

#define CAPTURE_FE                    ((u32)0x00000000) 
#define CAPTURE_RE                    ((u32)0x00000001) 

/**
 * @brief Enumeration of PWM channel.
 */
typedef enum
{
  PWM_Channel_1 = 0,                /*!< PWM channel 1 */
  PWM_Channel_2,                    /*!< PWM channel 2 */
  PWM_Channel_3,                    /*!< PWM channel 3 */
  PWM_Channel_4                     /*!< PWM channel 4 */
} PWM_CH_Enum;

/** @defgroup PWM_Channel
* @{ 
*/
#define IS_PWM_Channel(SEL) (((SEL) == PWM_Channel_1) ||\
														((SEL) == PWM_Channel_2)  ||\
														((SEL) == PWM_Channel_3)  ||\
														((SEL) == PWM_Channel_4))

/**
 * @brief  PWM channel_N  control.
 */

#define  PWM_CHNCTL_DISABLE           ((u32)0x00000000)      /*!< PWM channel_N disable */
#define  PWM_CHNCTL_ENABLE             PWM_OCMR_OC1NE           /*!< PWM channel_N enable */

/**
 * @brief  PWM channel output idle state.
 */

#define  PWM_IDLE_LOW                  ((u32)0x00000000)     /*!< PWM channel idle output low  */
#define  PWM_IDLE_HIGH                 PWM_OCMR_OIS1          /*!< PWM channel idle output high  */


/** @defgroup PWM_Count Mode 
  * @{
  */ 
#define PWM_CNT_MODE_UP                ((u32)0x00000000) 
#define PWM_CNT_MODE_DOWN              ((u32)0x00000040) 
#define PWM_CounterDirRv_EN            ((u32)0x00000080) 
#define PWM_CounterDirRv_DIS           ((u32)0x00000000) 

#define PWM_OCIT_ARI               PWM_CR2_ARI
#define PWM_OCIT_OC1I              PWM_CR2_OC1I        
#define PWM_OCIT_OC2I              PWM_CR2_OC2I      
#define PWM_OCIT_OC3I              PWM_CR2_OC3I      
#define PWM_OCIT_OC4I              PWM_CR2_OC4I      
#define PWM_ICIT_IC1I              PWM_CAPR_IC1I     
#define PWM_ICIT_IC2I              PWM_CAPR_IC2I     
#define PWM_ICIT_IC3I              PWM_CAPR_IC3I   
#define PWM_ICIT_IC4I              PWM_CAPR_IC4I     
#define PWM_BKIT_BKI               PWM_OCMR_BKI 


#define PWM_FLAG_ARF               PWM_SR_ARF
#define PWM_FLAG_OC1F              PWM_SR_OC1F        
#define PWM_FLAG_OC2F              PWM_SR_OC2F      
#define PWM_FLAG_OC3F              PWM_SR_OC3F      
#define PWM_FLAG_OC4F              PWM_SR_OC4F      
#define PWM_FLAG_IC1R              PWM_SR_IC1R     
#define PWM_FLAG_IC1F              PWM_SR_IC1F     
#define PWM_FLAG_IC2R              PWM_SR_IC2R     
#define PWM_FLAG_IC2F              PWM_SR_IC2F 
#define PWM_FLAG_IC3R              PWM_SR_IC3R     
#define PWM_FLAG_IC3F              PWM_SR_IC3F 
#define PWM_FLAG_IC4R              PWM_SR_IC4R     
#define PWM_FLAG_IC4F              PWM_SR_IC4F 
#define PWM_FLAG_BK                PWM_SR_BIF  


#define PWM_BreakPolarity_High              PWM_OCMR_BKP 
#define PWM_BreakPolarity_Low               ((u32)0x00000000) 
#define IS_PWM_BreakPolarity(LEVEL)        (((LEVEL) == PWM_BreakPolarity_High) || \
                                        ((LEVEL) == PWM_BreakPolarity_Low))

#define IS_PWM_ALL_PERIPH(PERIPH)            (((PERIPH) == PWM0) || \
                                              ((PERIPH) == PWM1))
																							
#define IS_PWM_REPEATTIME(TIMES)             ((TIMES) <= 0xF)

#define IS_PWM_COUNTER_RELOAD(RELOADVALUE)   ((RELOADVALUE) <= 0xFFFF)

#define IS_PWM_COUNTER_VALUE(COUNTERVALUE)   ((COUNTERVALUE) <= 0xFFFF)
                                           
#define IS_PWM_CHNCTL(CHNCTL)                (((CHNCTL) == PWM_CHNCTL_DISABLE) || \
                                              ((CHNCTL) == PWM_CHNCTL_ENABLE))

#define IS_PWM_IDLE(IDLE)                    (((IDLE) == PWM_IDLE_LOW)    || \
                                              ((IDLE) == PWM_IDLE_HIGH))			
#define IS_PWM_DEATHTIME(VALUE)              ((VALUE) <= 0xFF)

#define IS_PWM_Interrput(PWM_INT)              (((PWM_INT) == PWM_OCIT_ARI)  || ((PWM_INT) == PWM_OCIT_OC1I)  || \
                                              ((PWM_INT) == PWM_OCIT_OC2I)  || ((PWM_INT) == PWM_OCIT_OC3I)  || \
                                              ((PWM_INT) == PWM_OCIT_OC4I)  || ((PWM_INT) == PWM_BKIT_BKI))
																							
#define IS_PWM_CAP_INT(PWM_CAP_INT)			    (((PWM_CAP_INT) ==PWM_ICIT_IC1I) ||	((PWM_CAP_INT) ==PWM_ICIT_IC2I)	||\
                                              ((PWM_CAP_INT) ==PWM_ICIT_IC3I) || ((PWM_CAP_INT) ==PWM_ICIT_IC4I))
		
#define IS_PWM_PWM_FLAG(PWM_FLAG)            (((PWM_FLAG) == PWM_FLAG_ARF)     || ((PWM_FLAG) == PWM_FLAG_OC1F)     || \
                                              ((PWM_FLAG) == PWM_FLAG_OC2F)     || ((PWM_FLAG) == PWM_FLAG_OC3F)     || \
                                              ((PWM_FLAG) == PWM_FLAG_OC4F)     || ((PWM_FLAG) == PWM_FLAG_IC1R) || \
                                              ((PWM_FLAG) == PWM_FLAG_IC1F) || ((PWM_FLAG) == PWM_FLAG_IC2R) || \
																							((PWM_FLAG) == PWM_FLAG_IC2F) || ((PWM_FLAG) == PWM_FLAG_IC3R) || \
																							((PWM_FLAG) == PWM_FLAG_IC3F) || ((PWM_FLAG) == PWM_FLAG_IC4R) || \
																					    ((PWM_FLAG) == PWM_FLAG_IC4F) || ((PWM_FLAG) == PWM_FLAG_BK))	
#define IS_PWM_CLEAR_FLAG(FLAG)              ((FLAG)  <= 0X3FFF)																						
		

/**
 * @brief Definition of PWM timebase init structure.
 */

 
typedef struct
{
  u32  PWM_AutoReloadValue;         /*!< Period (Value for ARR register)             */
	u32  PWM_InternalClockSource;              /*!< Counting Clock select:HCLK or PCLK          */
  u32  PWM_Prescaler;             /*!< Prescaler (Value for PSC register)           */
  u32  PWM_Direction;           /*!< Counter mode up-counting or down-counting   */
  u32  PWM_CenterAlignedMode;       /*!< Counter Direction Reverse enable or disable */
} PWM_TimeBaseInitTypeDef;

/** @defgroup PWM_InternalClockSource
* @{ 
*/

#define IS_PWM_PRESCALER(PWM_Prescaler) ((PWM_Prescaler) <= 0xFF)
#define PWM_InternalClockSource_PCLK		0x00000000
#define PWM_InternalClockSource_SYSCLK	PWM_CR1_CLKS
#define IS_PWM_InternalClockSource(SEL)	(((SEL) == PWM_InternalClockSource_PCLK) || \
																				 ((SEL) == PWM_InternalClockSource_SYSCLK))
/** @defgroup PWM_Direction
* @{ 
*/
#define PWM_Direction_Up		(PWM_CR2_DIR&0x00000000) 
#define PWM_Direction_Down	(PWM_CR2_DIR&0x00000040)  
#define IS_PWM_Direction(SEL)      (((SEL) == PWM_Direction_Up) || \
																    ((SEL) == PWM_Direction_Down))   

/** @defgroup PWM_CenterAlignedMode
* @{ 
*/
#define PWM_CenterAlignedMode_Disable	(PWM_CR2_CMS&0x00000000)
#define PWM_CenterAlignedMode_Enable	(PWM_CR2_CMS&0x00000080)
#define IS_PWM_CenterAlignedMode(SEL)   (((SEL) == PWM_CenterAlignedMode_Disable) || \
																				 ((SEL) == PWM_CenterAlignedMode_Enable))  
																				 
#define IS_PWM_Prescaler(SEL)           ((SEL)<=65535)

#define IS_PWM_AutoReloadValue(SEL)     ((SEL)<=65535)

#define TIM_OCMode_Timing					(PWM_OCMR_OC1M&0x0000)
#define TIM_OCMode_PWM1						(PWM_OCMR_OC1M&0x0001)
#define TIM_OCMode_PWM2						(PWM_OCMR_OC1M&0x0002)
#define TIM_OCMode_Toggle					(PWM_OCMR_OC1M&0x0003)
#define IS_PWM_OCMode(SEL)         ((((SEL) &(~PWM_OCMR_OC1M))== 0x0) && ((SEL)<=TIM_OCMode_Toggle))

/** @defgroup PWM_OCIdleState
* @{ 
*/
#define  PWM_OCIdleState_Low		0x00000000
#define  PWM_OCIdleState_High		PWM_OCMR_OIS1
#define IS_PWM_OCIdleState(SEL)	(((SEL) == PWM_OCIdleState_Low)    || \
															   ((SEL) == PWM_OCIdleState_High))
															 
/** @defgroup PWM_OCNOutput
* @{ 
*/
#define  PWM_OCNOutput_Disable	0x00000000
#define  PWM_OCNOutput_Enable		PWM_OCMR_OC1NE
#define IS_PWM_OCNOutput(SEL)	(((SEL) == PWM_OCNOutput_Disable) || \
															 ((SEL) == PWM_OCNOutput_Enable))
															 
/**
 * @brief Definition of PWM channel output init structure.
 */
typedef struct
{
  PWM_CH_Enum    PWM_Channel;             
  u32    PWM_OCMode;           
  u32    PWM_OCNOutput;        
  u32    PWM_OCIdleState;      
  u32    PWM_OCValue;         
} PWM_OCInitTypeDef;

#define IS_PWM_OCValue(VALUE)           ((VALUE) <= 0xFFFF)
/* Exported functions --------------------------------------------------------------------------------------*/

/** @defgroup PWM_Exported_Functions PWM exported functions
  * @{
  */
void PMW_TimeBaseInit(PWM_TypeDef* PWMx, PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_TimeBaseStructInit(PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_OutputInit(PWM_TypeDef* PWMx, PWM_OCInitTypeDef* OutInit);
void PWM_INT_RepeatTimes(PWM_TypeDef* PWMx, u8 RepeatTimes);
void PWM_ClockSourceConfig(PWM_TypeDef* PWMx, u8 PWM_ClockSel);
void PWM_PrescalerConfig(PWM_TypeDef* PWMx, u8 Prescaler);
void PWM_SetCounterReload(PWM_TypeDef* PWMx, u16 Reload);
void PWM_SetCounter(PWM_TypeDef* PWMx, u16 Counter);	
void PWM_CounterModeConfig(PWM_TypeDef* PWMx, u8 PWM_Direction, u8 DirRv_EN);	
void PWM_UpdateCmd(PWM_TypeDef* PWMx);
void PWM_Cmd(PWM_TypeDef* PWMx, FunctionalState NewState);
void PWM_InterruptConfig(PWM_TypeDef* PWMx, u32 PWM_INT, FunctionalState NewState);
void PWM_ClearFlag(PWM_TypeDef* PWMx, u32 PWM_FLAG);
void PWM_RE_CaptureConfig(PWM_TypeDef* PWMx, u8 CHx, FunctionalState NewState);
void PWM_FE_CaptureConfig(PWM_TypeDef* PWMx, u8 CHx, FunctionalState NewState);
void PWM_RST_CaptureConfig(PWM_TypeDef* PWMx, u8 CHx, FunctionalState NewState);
void PWM_OD_Config(PWM_TypeDef* PWMx, u8 CHx, u32 Mode);
void PWM_IDLE_Config(PWM_TypeDef* PWMx, u8 CHx, u32 Idle);
void PWM_CHN_Config(PWM_TypeDef* PWMx, u8 CHx, u32 CHNCTL);
void PWM_DT_Config(PWM_TypeDef* PWMx, u8 CHx, u8 DeathTime);
void PWM_SetCompare(PWM_TypeDef* PWMx, u8 CHx, u16 Cmp);
FlagStatus PWM_GetFlagStatus(PWM_TypeDef* PWMx, u32 PWM_FLAG);
u16 PWM_GetCaptureCounter(PWM_TypeDef* PWMx, u8 CHx);
u16 PWM_GetCaptureEdge(PWM_TypeDef* PWMx, u8 CHx);
u16 PWM_GetCounter(PWM_TypeDef* PWMx);
u16 PWM_GetPrescaler(PWM_TypeDef* PWMx);
u16 PWM_GetPrescalerCnt(PWM_TypeDef* PWMx);
u8 PWM_GetINT_RepeatTimes(PWM_TypeDef* PWMx);
void PWM_BreakInput_Cmd(PWM_TypeDef* PWMx, FunctionalState NewState);
void PWM_BKI_LevelConfig(PWM_TypeDef* PWMx, u32 BKI_Level);
void PWM_CapITConfig(PWM_TypeDef* PWMx,u32 PWM_CAP_INT,FunctionalState NewState);


#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_PWM_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
