/**
  ******************************************************************************
  * @file    PT32x031x_pwr.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    2023/12/1
  * @brief   This file contains all the functions prototypes for the PWR firmware 
  *          library.
  ******************************************************************************
  * @attention
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_PWR_H
#define __PT32x031x_PWR_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup PWR
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup PWR_Exported_Constants
  * @{
  */ 

/** @defgroup PWR_PVD_detection_level 
  * @brief    
  * @{
  */ 

#define PWR_PVDLevel_2V0				((u32)(PWR_PVDR_PLS&0x00000000))
#define PWR_PVDLevel_1V7        ((u32)(PWR_PVDR_PLS&0x00000002))
#define PWR_PVDLevel_2V2        ((u32)(PWR_PVDR_PLS&0x00000004))
#define PWR_PVDLevel_2V5        ((u32)(PWR_PVDR_PLS&0x00000006))
#define PWR_PVDLevel_2V75       ((u32)(PWR_PVDR_PLS&0x00000008))
#define PWR_PVDLevel_3V0        ((u32)(PWR_PVDR_PLS&0x0000000A))
#define PWR_PVDLevel_3V5        ((u32)(PWR_PVDR_PLS&0x0000000C))

#define IS_PWR_PVD_LEVEL(LEVEL) (((LEVEL) == PWR_PVDLevel_2V0) || ((LEVEL) == PWR_PVDLevel_1V7)|| \
                                 ((LEVEL) == PWR_PVDLevel_2V2) || ((LEVEL) == PWR_PVDLevel_2V5)|| \
                                 ((LEVEL) == PWR_PVDLevel_2V75) || ((LEVEL) == PWR_PVDLevel_3V0)|| \
                                 ((LEVEL) == PWR_PVDLevel_3V5))

/** @defgroup PWR_WakeUp_Pins 
  * @{
  */

#define PWR_WakeUpPin_1                 PWR_CSR_EWUP1
#define PWR_WakeUpPin_2                 PWR_CSR_EWUP2
#define PWR_WakeUpPin_3                 PWR_CSR_EWUP3 
#define PWR_WakeUpPin_4                 PWR_CSR_EWUP4 
#define PWR_WakeUpPin_5                 PWR_CSR_EWUP5 
#define PWR_WakeUpPin_6                 PWR_CSR_EWUP6 
#define PWR_WakeUpPin_7                 PWR_CSR_EWUP7 
#define PWR_WakeUpPin_8                 PWR_CSR_EWUP8 
#define IS_PWR_WAKEUP_PIN(PIN) 					(((PIN) == PWR_WakeUpPin_1) || ((PIN) == PWR_WakeUpPin_2) || \
																				((PIN) == PWR_WakeUpPin_3) || ((PIN) == PWR_WakeUpPin_4) || \
																				((PIN) == PWR_WakeUpPin_5) || ((PIN) == PWR_WakeUpPin_6) || \
																				((PIN) == PWR_WakeUpPin_7) || ((PIN) == PWR_WakeUpPin_8))

 
/** @defgroup PWR_Regulator_state_is_Sleep_STOP_mode 
  * @{
  */

#define PWR_Regulator_ON                ((u32)0x00000000)
#define PWR_Regulator_LowPower          PWR_CR_LPSDSR
#define IS_PWR_REGULATOR(REGULATOR) 		(((REGULATOR) == PWR_Regulator_ON) || \
																				((REGULATOR) == PWR_Regulator_LowPower))

/** @defgroup PWR_SLEEP_mode_entry 
  * @{
  */

#define PWR_SLEEPEntry_WFI              ((u8)0x01)
#define PWR_SLEEPEntry_WFE              ((u8)0x02)
#define IS_PWR_SLEEP_ENTRY(ENTRY) 			(((ENTRY) == PWR_SLEEPEntry_WFI) || ((ENTRY) == PWR_SLEEPEntry_WFE))

/** @defgroup PWR_STOP_mode_entry 
  * @{
  */

#define PWR_DeepSleepEntry_WFI          ((u8)0x01)
#define PWR_DeepSleepEntry_WFE          ((u8)0x02)
#define IS_PWR_DEEPSLEEP_ENTRY(ENTRY) 	(((ENTRY) == PWR_DeepSleepEntry_WFI) || ((ENTRY) == PWR_DeepSleepEntry_WFE))

/** @defgroup PWR_Flag 
  * @{
  */

#define PWR_FLAG_WU                     PWR_CSR_WUF
#define PWR_FLAG_SB                     PWR_CSR_SBF
#define PWR_FLAG_PVDO                   PWR_CSR_PVDO 
#define PWR_FLAG_VREFINTRDY             PWR_CSR_VREFINTRDYF 

#define IS_PWR_GET_FLAG(FLAG) 					(((FLAG) == PWR_FLAG_WU) || ((FLAG) == PWR_FLAG_SB) || \
																				((FLAG) == PWR_FLAG_PVDO) || ((FLAG) == PWR_FLAG_VREFINTRDY))

#define IS_PWR_CLEAR_FLAG(FLAG) 				(((FLAG) == PWR_FLAG_WU) || ((FLAG) == PWR_FLAG_SB))
/**
  * @}
  */

/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
/* Function used to set the PWR configuration to the default reset state ******/
/* Backup Domain Access function **********************************************/
/* PVD configuration functions ************************************************/
/* WakeUp pins configuration functions ****************************************/
/* Low Power modes configuration functions ************************************/
/* Flags management functions *************************************************/
void PWR_PVDLevelConfig(u32 PWR_PVDLevel);
void PWR_PVDCmd(FunctionalState NewState);
void PWR_EnterSleepMode(u8 PWR_SLEEPEntry);
void PWR_EnterDeepSleepMode(u8 PWR_DeepStandbyEntry);

#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_PWR_H */

/**
  * @}
  */

/**
  * @}
  */

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
