/******************************************************************************
* @file    PT32x031x_rcc.h
* @author  ӦÿŶ
* @version V1.0.0
* @date    2023/12/1
* @brief    This file contains all the functions prototypes for the SYS firmware library.
*
******************************************************************************
* @attention
*
*
*****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x031x_RCC_H
#define PT32x031x_RCC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup RCC
  * @{
  */
#define RCC_HSI          ((u32)0x00000000)        /*!<  */
#define RCC_HSE          ((u32)0x00000001)        /*!<  */
#define RCC_PLL          ((u32)0x00000002)        /*!<  */
#define RCC_LSI          ((u32)0x00000003)        /*!<  */
#define RCC_HSE_External	((u32)0x00000004)        /*!<  */

#define IS_RCC_ClockSource(ClockSource) ((ClockSource==RCC_HSI) ||\
																				(ClockSource==RCC_HSI) ||\
																				(ClockSource==RCC_HSI) ||\
																				(ClockSource==RCC_HSI) ||\
																				(ClockSource==RCC_HSI) ||\
																				(ClockSource==RCC_HSI))

typedef enum
{
	RCC_SysClock=0,
	RCC_HCLK,
	RCC_PCLK
} Clock_TypeDef;
#define IS_RCC_Clock(SEL)   				 ((SEL)<=0x2)

#define PLLCLK_SEL_HSI           ((u32)0x00000000)        /*!<  */
#define PLLCLK_SEL_HSE            ((u32)0x00000004)        /*!<  */
#define PLLCLK_SEL_LSI           ((u32)0x00000008)        /*!<  */
/* Exported types ------------------------------------------------------------*/


/* Exported constants --------------------------------------------------------*/

/* Exported types ------------------------------------------------------------*/

/**
 * @brief Enumeration of Global reset status.
 */

#define RCC_ResetEnable_HREN      RCC_RCR_HREN
#define RCC_ResetEnable_PREN      RCC_RCR_PREN
#define RCC_ResetEnable_PDRE      RCC_RCR_PDRE
#define RCC_ResetEnable_ASFREN    RCC_RCR_ASFREN
#define IS_RCC_ResetEnable(SEL)    ((SEL == RCC_ResetEnable_HREN) ||\
																		(SEL == RCC_ResetEnable_PREN) ||\
																		(SEL == RCC_ResetEnable_PDRE) ||\
																		(SEL == RCC_ResetEnable_ASFREN))

/** @defgroup RCC_Reset_State_Flag
  * @{
  */
#define RCC_FLAG_SFR       		 			 RCC_RSR_SFR
#define RCC_FLAG_IWDG       				 RCC_RSR_IWDG
#define RCC_FLAG_SWDG     					 RCC_RSR_SWDG
#define RCC_FLAG_HSE      					 RCC_RSR_HSE
#define RCC_FLAG_PLL       		  		 RCC_RSR_PLL
#define RCC_FLAG_POR       			 		 RCC_RSR_POR
#define RCC_FLAG_PIN      		 			 RCC_RSR_PIN
#define RCC_FLAG_PVD     			  		 RCC_RSR_PVD

#define RCC_FLAG_ALL     						 (u32)(0x1FB) 
#define IS_RCC_ResetStatusFlag(SEL)       ((((SEL) & ~RCC_FLAG_ALL) == 0) && ((SEL) !=0x0000))

/**
  * @};
  */


/* Exported constants --------------------------------------------------------*/

/** @defgroup SYS_Exported_Constants
  * @{
  */

#define KEY_RETRIMING                            0x0000AB56     

/** @addtogroup SYS_Exported_Functions
  * @{
  */
void RCC_AutomaticAmplitude(FunctionalState NewState);
u32 RCC_GetClockFreq(u8 RCC_Clock);
RemapStatus System_GetRemapStatus(void);
void System_ResetRemapBit(void);
void System_Retriming(void);
FlagStatus RCC_GetResetFlagStatus(u32 reset_flag);
void RCC_ClearResetFlag(u32 reset_flag);
void System_ClearAllResetFlag(void);
void RCC_ResetConfig(u32 RstSource, FunctionalState NewState);
u32 System_GetAgentID(void);
u32 System_GetCD(void);
void RCC_ClockSourceConfig(u32 ClockSource, FunctionalState NewState);
/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif /*__PT32S038x_RCC_H */
