/**
  ******************************************************************************
  * @file    PT32x031x_spi.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031x_SPI_H
#define __PT32x031x_SPI_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup SPI
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** 
  * @brief  SPI Init structure definition  
  */

typedef struct
{
  u16 SPI_Direction;           /*!< Specifies the SPI unidirectional or bidirectional data mode.
                                         This parameter can be a value of @ref SPI_data_direction */

  u16 SPI_Mode;                /*!< Specifies the SPI mode (Master/Slave).
                                         This parameter can be a value of @ref SPI_mode */
  
  u16 SPI_DataSize;            /*!< Specifies the SPI data size.
                                         This parameter can be a value of @ref SPI_data_size */

  u16 SPI_CPOL;                /*!< Specifies the serial clock steady state.
                                         This parameter can be a value of @ref SPI_Clock_Polarity */

  u16 SPI_CPHA;                /*!< Specifies the clock active edge for the bit capture.
                                         This parameter can be a value of @ref SPI_Clock_Phase */

  u16 SPI_NSS;                 /*!< Specifies whether the NSS signal is managed by
                                         hardware (NSS pin) or by software using the SSI bit.
                                         This parameter can be a value of @ref SPI_Slave_Select_management */
 
  u8 SPI_BaudRatePrescaler;   /*!< Specifies the Baud Rate prescaler value which will be
                                         used to configure the transmit and receive SCK clock.
                                         This parameter can be a value of @ref SPI_BaudRate_Prescaler
                                         @note The communication clock is derived from the master
                                               clock. The slave clock does not need to be set. */
  u8 SPI_BaudRatePostPrescaler; /*!< Specifies the Baud Rate prescaler value which will be
                                         used to configure the transmit and receive SCK clock.
                                         This parameter can be a value of @ref SPI_BaudRate_Prescaler
                                         @note The communication clock is derived from the master
                                               clock. The slave clock does not need to be set. */																							 
																							 
}SPI_InitTypeDef;



/* Exported constants --------------------------------------------------------*/

/** @defgroup SPI_Exported_Constants
  * @{
  */

#define IS_SPI_ALL_PERIPH(PERIPH) 			(((PERIPH) == SPI0) || \
																				((PERIPH) == SPI1))
                                   

/** @defgroup SPI_mode 
  * @{
  */

#define SPI_Mode_Master                 ((u16)0x0000)
#define SPI_Mode_Slave                  ((u16)0x0004)
#define IS_SPI_MODE(MODE) 							(((MODE) == SPI_Mode_Master) || \
																				((MODE) == SPI_Mode_Slave))
/**
  * @}
  */

/** @defgroup SPI_data_size
  * @{
  */

#define SPI_DataSize_4b                  (SPI_CR1_DFF&0x3)
#define SPI_DataSize_5b                  (SPI_CR1_DFF&0x4)
#define SPI_DataSize_6b                  (SPI_CR1_DFF&0x5)
#define SPI_DataSize_7b                  (SPI_CR1_DFF&0x6)
#define SPI_DataSize_8b                  (SPI_CR1_DFF&0x7)
#define SPI_DataSize_9b                  (SPI_CR1_DFF&0x8)
#define SPI_DataSize_10b                 (SPI_CR1_DFF&0x9)
#define SPI_DataSize_11b                 (SPI_CR1_DFF&0xA)
#define SPI_DataSize_12b                 (SPI_CR1_DFF&0xB)
#define SPI_DataSize_13b                 (SPI_CR1_DFF&0xC)
#define SPI_DataSize_14b                 (SPI_CR1_DFF&0xD)
#define SPI_DataSize_15b                 (SPI_CR1_DFF&0xE)
#define SPI_DataSize_16b                 (SPI_CR1_DFF&0xF)
#define IS_SPI_DATA_SIZE(SIZE) 					 (((SIZE) == SPI_DataSize_4b) || \
																				 ((SIZE) == SPI_DataSize_5b) || \
																				 ((SIZE) == SPI_DataSize_6b) || \
																				 ((SIZE) == SPI_DataSize_7b) || \
																				 ((SIZE) == SPI_DataSize_8b) || \
																				 ((SIZE) == SPI_DataSize_9b) || \
																				 ((SIZE) == SPI_DataSize_10b) || \
																				 ((SIZE) == SPI_DataSize_11b) || \
																				 ((SIZE) == SPI_DataSize_12b) || \
																				 ((SIZE) == SPI_DataSize_13b) || \
																				 ((SIZE) == SPI_DataSize_14b) || \
																				 ((SIZE) == SPI_DataSize_15b) || \
																				 ((SIZE) == SPI_DataSize_16b))
/**
  * @}
  */


/** @defgroup SPI_Clock_Polarity 
  * @{
  */

#define SPI_CPOL_Low                    ((u16)0x0000)
#define SPI_CPOL_High                   SPI_CR1_CPOL
#define IS_SPI_CPOL(CPOL) 							(((CPOL) == SPI_CPOL_Low) || \
																				((CPOL) == SPI_CPOL_High))
/**
  * @}
  */

/** @defgroup SPI_Clock_Phase 
  * @{
  */

#define SPI_CPHA_1Edge                  ((u16)0x0000)
#define SPI_CPHA_2Edge                  SPI_CR1_CPHA
#define IS_SPI_CPHA(CPHA) 							(((CPHA) == SPI_CPHA_1Edge) || \
																				((CPHA) == SPI_CPHA_2Edge))
/**
  * @}
  */

/** @defgroup SPI_Slave_Select_management 
  * @{
  */

#define SPI_NSS_Soft                    SPI_CSS_CSS
#define SPI_NSS_Hard                    ((u16)0x0000)
#define IS_SPI_NSS(NSS) 								(((NSS) == SPI_NSS_Soft) || \
																				((NSS) == SPI_NSS_Hard))
/**
  * @}
  */

/** @defgroup SPI_BaudRate_Prescaler 
  * @{
  */

#define IS_SPI_BAUDRATE_PRESCALER(PRESCALER) 					((PRESCALER%2) == 0)																																																														
#define IS_SPI_BAUDRATE_POSTPRESCALER(POSTPRESCALER)  ((POSTPRESCALER) <= 0xFF )																							


/**
  * @}
  */
/** @defgroup SPI_NSS_internal_software_management 
  * @{
  */

#define SPI_NSSInternalSoft_Set         SPI_CSS_SWCS
#define SPI_NSSInternalSoft_Reset       ((u16)0xFFF7)
#define IS_SPI_NSS_INTERNAL(INTERNAL) (((INTERNAL) == SPI_NSSInternalSoft_Set) || \
                                       ((INTERNAL) == SPI_NSSInternalSoft_Reset))
/**
  * @}
  */

/** @defgroup SPI_interrupts_definition 
  * @{
  */

#define SPI_IT_RFOF                  SPI_IE_OVRE
#define SPI_IT_RFNEOT                SPI_IE_OTE
#define SPI_IT_RFHF                  SPI_IE_RXHE
#define SPI_IT_TFHF                  SPI_IE_TXHE

#define IS_SPI_CONFIG_IT(IT) 				(((IT) == SPI_IT_RFOF) || \
  																	((IT) == SPI_IT_RFNEOT) || \
	 																	((IT) == SPI_IT_RFHF) || \
																		((IT) == SPI_IT_TFHF))
																	
#define IS_SPI_GET_IT(IT) 					(((IT) == SPI_IT_RFOF) || \
                                    ((IT) == SPI_IT_RFNEOT) || \
																		((IT) == SPI_IT_RFHF) || \
																		((IT) == SPI_IT_TFHF))


/** @defgroup SPI_flags_definition 
  * @{
  */
#define SPI_FLAG_TFE                    SPI_SR1_TXE                 
#define SPI_FLAG_TFNF                   SPI_SR1_TNF    
#define SPI_FLAG_RFNE                   SPI_SR1_RXNE 
#define SPI_FLAG_RFF                    SPI_SR1_RXF     
#define SPI_FLAG_BUSY                   SPI_SR1_BSY   

#define SPI_FLAG_RFOVF                  SPI_SR2_OVR                 
#define SPI_FLAG_RFNETO                 SPI_SR2_OT    
#define SPI_FLAG_RFHF                   SPI_SR2_RXH 
#define SPI_FLAG_TFHF                   SPI_SR2_TXH 

#define IS_SPI_CLEAR_FLAG(FLAG) 				(((FLAG) == SPI_FLAG_RFOVF) || ((FLAG) == SPI_FLAG_RFNETO))
#define IS_SPI_GET_FLAG(FLAG) 					(((FLAG) == SPI_FLAG_TFE) || ((FLAG) == SPI_FLAG_TFNF) || \
																				((FLAG) == SPI_FLAG_RFNE) || ((FLAG) == SPI_FLAG_RFF) || \
																				((FLAG) == SPI_FLAG_BUSY))

/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

void SPI_StructInit(SPI_InitTypeDef* SPI_InitStruct);
void SPI_Init(SPI_TypeDef* SPIx, SPI_InitTypeDef* SPI_InitStruct);
void SPI_Cmd(SPI_TypeDef* SPIx, FunctionalState NewState);
void SPI_DataSizeConfig(SPI_TypeDef* SPIx, u16 SPI_DataSize);
void SPI_NSSInternalSoftwareConfig(SPI_TypeDef* SPIx, u16 SPI_NSSInternalSoft);
void SPI_SendData8(SPI_TypeDef* SPIx, u8 Data);
u8 SPI_ReceiveData8(SPI_TypeDef* SPIx);
void SPI_ITConfig(SPI_TypeDef* SPIx, u8 SPI_IT, FunctionalState NewState);
FlagStatus SPI_GetFlagStatus(SPI_TypeDef* SPIx, u16 SPI_FLAG);
void SPI_ClearFlag(SPI_TypeDef* SPIx, u16 SPI_FLAG);
u16 SPI_ReceiveData(SPI_TypeDef* SPIx);
void SPI_SendData(SPI_TypeDef* SPIx, u16 Data);

#ifdef __cplusplus
}
#endif

#endif /*__PT32x031_SPI_H */

/**
  * @}
  */

/**
  * @}
  */

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
