/**
  ******************************************************************************
  * @file    PT32x031x_tim.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1   
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  * 
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031_TIM_H
#define __PT32x031_TIM_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup TIM
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

#define IS_TIM_ALL_PERIPH(SEL)  (((SEL) == TIM2) || ((SEL) == TIM3) || ((SEL) == TIM4))

#define IS_TIM_Prescaler(SEL) 	((SEL&(u32)0xFFFFFF00)==0)

#define TIM_IT_ARI  	TIM_CR2_ARI

#define IS_TIM_IT(TIM_INT)			((TIM_INT)  == TIM_IT_ARI)   

#define TIM_FLAG_ARF  TIM_SR_ARF 
#define IS_TIM_FLAG(SEL) ((SEL) == TIM_FLAG_ARF)
 /** @defgroup TIM_Direction
* @{
*/
#define TIM_Direction_Up				(TIM_CR2_DIR&0x00000000)
#define TIM_Direction_Down			(TIM_CR2_DIR&0x00000008)
#define IS_TIM_Direction(SEL)      (((SEL) == TIM_Direction_Up) || \
																		((SEL) == TIM_Direction_Down))

#define IS_TIM_AutoReloadValue(value) ((value&(u32)0xFFFF0000)==0) 
typedef struct
{ 
  u32  TIM_AutoReloadValue;     /*!< Period (Value for ARR register)             */
  u32  TIM_Prescaler;           /*!< Prescaler (Value for PSC register)           */
	u32  TIM_Direction;           /*!< Counter mode up-counting or down-counting   */
	FunctionalState TIM_ResetCounter;/*!<Reset counter disable or enable*/
} TIM_TimeBaseInitTypeDef;      


/* Exported functions --------------------------------------------------------------------------------------*/

/** @defgroup TIM_Exported_Functions TIM exported functions
  * @{
  */

void TIM_TimeBaseInit(TIM_TypeDef* TIMx, TIM_TimeBaseInitTypeDef* TimeBaseInit);
void TIM_TimeBaseStructInit(TIM_TimeBaseInitTypeDef* TimeBaseInit);
void TIM_PrescalerConfig(TIM_TypeDef* TIMx, u8 Prescaler);
void TIM_SetCounterMatch(TIM_TypeDef* TIMx, u16 Reload);
void TIM_SetCounter(TIM_TypeDef* TIMx, u16 Counter);
u16 TIM_GetCounter(TIM_TypeDef* TIMx);
u16 TIM_GetPrescaler(TIM_TypeDef* TIMx);
void TIM_DirectionConfig(TIM_TypeDef* TIMx, u8 CounterMode);
void TIM_UpdateCmd(TIM_TypeDef* TIMx, FunctionalState NewState);
void TIM_Cmd(TIM_TypeDef* TIMx, FunctionalState NewState);
void TIM_ITConfig(TIM_TypeDef* TIMx, u32 TIM_IT, FunctionalState NewState);
FlagStatus TIM_GetFlagStatus(TIM_TypeDef* TIMx, u32 TIM_FLAG);
void TIM_ClearFlag(TIM_TypeDef* TIMx, u32 TIM_FLAG);



#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_TIM_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
