/**
  ******************************************************************************
  * @file    PT32x031x_uart.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1  
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031_UART_H
#define __PT32x031_UART_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup UART
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
   
/** 
  * @brief  UART Init Structure definition  
  */ 
typedef struct
{
  u32 UART_BaudRate;
  u16 UART_WordLength;
  u16 UART_StopBit;
  u16 UART_Parity;
	u16 UART_RXEN;
} UART_InitTypeDef;

/** @defgroup UART_FIFO_TYPE
  * @{
  */ 
typedef enum 
{ 
  Rx_FIFO, 
  Tx_FIFO
} UART_FifoTypeDef;

/**
  * @}
  */ 

/** @defgroup UART_Oversampling_Rate
  * @{
  */ 
#define IS_UART_ALL_PERIPH(PERIPH)     (((PERIPH) == UART0) || \
                                       ((PERIPH) == UART1))

#define IS_USART_0_PERIPH(PERIPH)      ((PERIPH) == UART0)

#define UART_SAMPLERATEX4              ((u32)0x00000004)
#define UART_SAMPLERATEX8              ((u32)0x00000008)
#define UART_SAMPLERATEX16             ((u32)0x00000010)

#define IS_UART_BAUDRATE(BAUDRATE)     (((BAUDRATE) > 0) && ((BAUDRATE) < 0x005B8D81))
#define IS_UART_SAMPLERATE(SAMPLERATE) (((SAMPLERATE) == UART_SAMPLERATEX4) || ((SAMPLERATE) == UART_SAMPLERATEX8) || \
                                       ((SAMPLERATE) == UART_SAMPLERATEX16))	
#define IS_UART_RXSTATUS(RXSTATUS)     (((RXSTATUS) == ENABLE) || ((RXSTATUS) == DISABLE))	

/**
  * @}
  */ 

/** @defgroup UART_Global_definition 
  * @{
  */
#define IS_UART_TIMEOUT(TIMEOUT)       ((TIMEOUT) <= 0x000000FF)
#define IS_UART_PRESCALER(PRESCALER)   ((PRESCALER) <= 0x00000005)
#define IS_UART_DATA(DATA)             ((DATA) <= 0x1FF)
#define IS_UART_DUTYCYCLE(DUTYCYCLE)   ((DUTYCYCLE) <= 0x00000064)

/**
  * @}
  */ 
	
/** @defgroup UART_Frame_Formate 
  * @{
  */ 
#define UARTM_8D                       ((u32)0x00000001)
#define UARTM_7D_P                     ((u32)0x00000003)
#define UARTM_9D                       ((u32)0x00000004)
#define UARTM_8D_W                     ((u32)0x00000005)
#define UARTM_8D_P                     ((u32)0x00000007)

#define UART05StopBits                 ((u32)0x00000000)
#define UART1StopBit                   ((u32)0x00000008)
#define UART15StopBits                 ((u32)0x00000010)
#define UART2StopBits                  ((u32)0x00000018)



#define IS_UART_WORD_LENGTH(LENGTH)    (((LENGTH) == UARTM_8D) || ((LENGTH) == UARTM_7D_P) || \
                                       ((LENGTH) == UARTM_9D) || ((LENGTH) == UARTM_8D_W)  || \
                                       ((LENGTH) == UARTM_8D_P))
																			
#define IS_UART_STOPBITS(STOPBITS)     (((STOPBITS) == UART05StopBits) || ((STOPBITS) == UART1StopBit) || \
                                       ((STOPBITS) == UART15StopBits) || ((STOPBITS) == UART2StopBits))			
/**
  * @}
  */ 

/** @defgroup UART_HalfDuplex_Mode 
  * @{
  */ 

#define UART_Mode_Rx                   ((u32)0x00000000)
#define UART_Mode_Tx                   ((u32)0x00000001)
#define IS_UART_MODE(MODE)             (((MODE) == UART_Mode_Tx) || \
                                       ((MODE) == UART_Mode_Rx))
/**
  * @}
  */ 

/** @defgroup UART_Polarity_Mode 
  * @{
  */ 

#define UART_InvPin_Tx                  UART_CR_TXP
#define UART_InvPin_Rx                  UART_CR_RXP
#define IS_UART_INVERSTION_PIN(PIN)     ((((PIN) & (u32)0xFFFCFFFF) == 0x00) && \
                                        ((PIN) != (u32)0x00))																				
																				
/**
  * @}
  */ 

/** @defgroup UART_Polarity_Mode 
  * @{
  */ 
#define UART_ODD_PARITY                ((u32)0x00000020)
#define UART_EVEN_PARITY               ((u32)0x00000000)
#define IS_UART_PARITY(MODE)           (((MODE) == UART_ODD_PARITY) || \
                                       ((MODE) == UART_EVEN_PARITY))
/**
  * @}
  */ 

/** @defgroup USART_Flags 
  * @{
  */
#define  UART_FLAG_RXNE                      UART_SR_RXNE          /*!< Receiver FIFO buffer non-empty */
#define  UART_FLAG_RXHF                      UART_SR_RXHF          /*!< Receiver FIFO buffer half-full */
#define  UART_FLAG_RXF                       UART_SR_RXF           /*!< Receiver FIFO buffer full */
#define  UART_FLAG_TONE                      UART_SR_RXCOT          /*!< Receiver FIFO buffer cleared timeout  */
#define  UART_FLAG_TOIDLE                    UART_SR_IDLE        /*!< Receiver FIFO buffer idel */
#define  UART_FLAG_PERR                      UART_SR_PE          /*!< Parity error */      
#define  UART_FLAG_FERR                      UART_SR_FE          /*!< Frame error */
#define  UART_FLAG_OVERR                     UART_SR_OVR         /*!< Receiver FIFO buffer overflow */    
#define  UART_FLAG_TXE                       UART_SR_TXE           /*!< Transmitter FIFO buffer empty */         
#define  UART_FLAG_TXHE                      UART_SR_TXHE          /*!< Transmitter FIFO buffer half-empty */       
#define  UART_FLAG_TXF                       UART_SR_TXF           /*!< Transmitter FIFO buffer full */   
#define  UART_FLAG_TXEND                     UART_SR_TXO         /*!< Transfer completed */

#define IS_UART_FLAG(FLAG)  (((FLAG) == UART_FLAG_RXNE)   || ((FLAG) == UART_FLAG_RXHF)  || \
                             ((FLAG) == UART_FLAG_RXF)    || ((FLAG) == UART_FLAG_TONE)  || \
                             ((FLAG) == UART_FLAG_TOIDLE) || ((FLAG) == UART_FLAG_PERR)  || \
                             ((FLAG) == UART_FLAG_FERR)   || ((FLAG) == UART_FLAG_OVERR) || \
                             ((FLAG) == UART_FLAG_TXE)    || ((FLAG) == UART_FLAG_TXHE)  || \
                             ((FLAG) == UART_FLAG_TXF)    || ((FLAG) == UART_FLAG_TXEND)) 
														 
#define  UART_CLEAR_FLAG_PERR                      UART_SR_PE  >> 0x01          /*!< Parity error */      
#define  UART_CLEAR_FLAG_FERR                      UART_SR_FE  >> 0x01          /*!< Frame error */
#define  UART_CLEAR_FLAG_OVERR                     UART_SR_OVR >> 0x01          /*!< Receiver FIFO buffer overflow */ 


#define IS_UART_CLEAR_FLAG(FLAG)  (((FLAG) == UART_CLEAR_FLAG_PERR)   || ((FLAG) == UART_CLEAR_FLAG_FERR)  ||\
                                   ((FLAG) == UART_CLEAR_FLAG_OVERR))
/**
  * @}
  */ 
	
/** @defgroup UART_Interrupt_definition                                                                                                                           
  * @brief UART Interrupt definition                                                                                                                                                               
  * @{                                                                                                          
  */                                                                                                            
                                                                                                                
#define  UART_IT_RXNEIE                     UART_IE_RXNEI          /*!< Receiver FIFO buffer non-empty */                                          
#define  UART_IT_RXHFIE                     UART_IE_RXHFI          /*!< Receiver FIFO buffer half-full */                                          
#define  UART_IT_RXFIE                      UART_IE_RXFI           /*!< Receiver FIFO buffer full */                                               
#define  UART_IT_TONEIE                     UART_IE_RXCOTI          /*!< Receiver FIFO buffer cleared timeout  */                                   
#define  UART_IT_TOIDLEIE                   UART_IE_IDLEI        /*!< Receiver FIFO buffer idel */                                               
#define  UART_IT_PERRIE                     UART_IE_PEI          /*!< Parity error */                                                            
#define  UART_IT_FERRIE                     UART_IE_FEI          /*!< Frame error */                                                             
#define  UART_IT_OVERRIE                    UART_IE_OVRI         /*!< Receiver FIFO buffer overflow */                                           
#define  UART_IT_TXEIE                      UART_IE_TXEI           /*!< Transmitter FIFO buffer empty */                                           
#define  UART_IT_TXHEIE                     UART_IE_TXHI          /*!< Transmitter FIFO buffer half-empty */                                      
#define  UART_IT_TXFIE                      UART_IE_TXFI           /*!< Transmitter FIFO buffer full */                                            
#define  UART_IT_TXENDIE                    UART_IE_TXOI         /*!< Transfer completed */                                               


#define IS_UART_CONFIG_IT(SOURCE) (((SOURCE) == UART_IT_RXNEIE) || ((SOURCE) == UART_IT_RXHFIE) || \
                                    ((SOURCE) == UART_IT_RXFIE) || ((SOURCE) == UART_IT_TONEIE) || \
                                    ((SOURCE) == UART_IT_TOIDLEIE) || ((SOURCE) == UART_IT_PERRIE) || \
                                    ((SOURCE) == UART_IT_FERRIE) || ((SOURCE) == UART_IT_OVERRIE) || \
                                    ((SOURCE) == UART_IT_TXEIE) || ((SOURCE) == UART_IT_TXHEIE) || \
                                    ((SOURCE) == UART_IT_TXFIE) || ((SOURCE) == UART_IT_TXENDIE))
																		
#define IS_UART_GET_IT(IT)         (((IT) == UART_IT_RXNEIE) || ((IT) == UART_IT_RXHFIE) || \
                                    ((IT) == UART_IT_RXFIE) || ((IT) == UART_IT_TONEIE) || \
                                    ((IT) == UART_IT_TOIDLEIE) || ((IT) == UART_IT_PERRIE) || \
                                    ((IT) == UART_IT_FERRIE) || ((IT) == UART_IT_OVERRIE) || \
                                    ((IT) == UART_IT_TXEIE) || ((IT) == UART_IT_TXHEIE) || \
                                    ((IT) == UART_IT_TXFIE) || ((IT) == UART_IT_TXENDIE))																		
																
/**
  * @}
  */ 

void UART_Init(UART_TypeDef* UARTx, UART_InitTypeDef* UART_InitStruct);
void UART_StructInit(UART_InitTypeDef* UART_InitStruct);
void UART_Cmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_RxConfig(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_InverPolarityCmd(UART_TypeDef* UARTx, u32 UART_InvPin, FunctionalState NewState);
void UART_SetReceiverTimeOut(UART_TypeDef* UARTx, u32 UART_ReceiverTimeOut);
void UART_SetPrescaler(UART_TypeDef* UARTx, u8 UART_Prescaler);
void UART_SendData(UART_TypeDef* UARTx, u16 Data);
void UART_StringSend(UART_TypeDef* UARTx, u8 *String);
u16 UART_ReceiveData(UART_TypeDef* UARTx);
u16 UART_ReceiveData_Timeout(UART_TypeDef* UARTx, u16 *Data, u32 UART_ReceiverTimeOut);
u16 UART_StringReceive(UART_TypeDef* UARTx, u8 *Data);
void UART_LoopBackConfig(UART_TypeDef* UARTx, FunctionalState NewStatus);
void UART_FifoReset(UART_TypeDef * UARTx,  UART_FifoTypeDef FIFO);
void UART_IrDACmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_IrDAInvPinCmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_SetDutyCycle(UART_TypeDef* UARTx, u8 UART_DutyCycle);
void UART_HalfDuplexCmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_HalfDuplex_DirectionModeCmd(UART_TypeDef* UARTx, u32 UART_DirectionMode);
void UART_ITConfig(UART_TypeDef* UARTx, u32 UART_IT, FunctionalState NewState);
FlagStatus UART_GetFlagStatus(UART_TypeDef* UARTx, u32 UART_FLAG);
void UART_ClearFlag(UART_TypeDef* UARTx, u32 UART_CLEAR_FLAG);
ITStatus UART_GetITStatus(UART_TypeDef* UARTx,u32 UART_IT);

#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_UART_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
