/**
  ******************************************************************************
  * @file    PT32x031x_wdg.h
  * @author  Application Team
  * @version V1.0.0
  * @date    2023/12/1
  * @brief   This file contains all the functions prototypes for the IWDG 
  *          firmware library.
  ******************************************************************************
  * @attention
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PT32x031_WDG_H
#define __PT32x031_WDG_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x031x.h"

/** @addtogroup PT32x031_StdPeriph_Driver
  * @{
  */

/** @addtogroup WDG
  * @{
  */

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup WDG_Exported_Constants
  * @{
  */

/** @defgroup WDG_WriteAccess
  * @{
  */

#define IS_WDG_ALL_PERIPH(PERIPH)     (((PERIPH) == IWDG) || \
                                       ((PERIPH) == SWDG))

#define WDG_LockKey_Unlock     ((uint32_t)0x1ACCE551)
#define WDG_LockKey_Lock    ((uint32_t)0x00000000)
#define IS_WDG_WRITE_ACCESS(ACCESS) (((ACCESS) == WDG_LockKey_Unlock) || \
                                     ((ACCESS) == WDG_LockKey_Lock))
/**
  * @}
  */

/** @defgroup IWDG_prescaler 
  * @{
  */

#define WDG_Prescaler_4            ((uint8_t)0x00)
#define WDG_Prescaler_8            ((uint8_t)0x01)
#define WDG_Prescaler_16           ((uint8_t)0x02)
#define WDG_Prescaler_32           ((uint8_t)0x03)
#define WDG_Prescaler_64           ((uint8_t)0x04)
#define WDG_Prescaler_128          ((uint8_t)0x05)
#define WDG_Prescaler_256          ((uint8_t)0x06)
#define IS_WDG_PRESCALER(PRESCALER) (((PRESCALER) == WDG_Prescaler_4)  || \
                                     ((PRESCALER) == WDG_Prescaler_8)  || \
                                     ((PRESCALER) == WDG_Prescaler_16) || \
                                     ((PRESCALER) == WDG_Prescaler_32) || \
                                     ((PRESCALER) == WDG_Prescaler_64) || \
                                     ((PRESCALER) == WDG_Prescaler_128)|| \
                                     ((PRESCALER) == WDG_Prescaler_256))
/**
  * @}
  */

/** @defgroup IWDG_Flag 
  * @{
  */

#define WDG_FLAG_RVU                 WDG_RIS_RVU
#define IS_WDG_FLAG(FLAG)           (((FLAG) == WDG_FLAG_RVU))


#define WDG_IT_RVU                   WDG_EIS_RVU
#define IS_WDG_FLAG(FLAG)           (((FLAG) == WDG_FLAG_RVU))
#define IS_WDG_GET_IT(IT) (((IT) == WDG_IT_RVU))

#define IS_WDG_RELOAD(RELOAD) ((RELOAD) <= 0xFFFFFFFF)

/**
  * @}
  */

/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
/* Prescaler and Counter configuration functions ******************************/
/* IWDG activation function ***************************************************/
/* Flag management function ***************************************************/

void WDG_LockCmd(WDG_TypeDef* WDGx, uint32_t WDG_WriteAccess);
void WDG_SetReload(WDG_TypeDef* WDGx, uint32_t Reload);
void WDG_ReloadCounter(WDG_TypeDef* WDGx);
void WDG_AccessEnable(WDG_TypeDef* WDGx, FunctionalState NewState);
void WDG_Cmd(WDG_TypeDef* WDGx, FunctionalState NewState);
FlagStatus WDG_GetFlagStatus(WDG_TypeDef* WDGx, u32 WDG_FLAG);
FlagStatus WDG_GetLockStatus(WDG_TypeDef* WDGx);
void WDG_ResetCmd(WDG_TypeDef* WDGx, FunctionalState NewState);
void WDG_DbgeRunCmd(WDG_TypeDef* WDGx, FunctionalState NewState);
#ifdef __cplusplus
}
#endif

#endif /* __PT32x031_IWDG_H */

/**
  * @}
  */

/**
  * @}
  */

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
